@@ -1,7 +1,8 @@
--- luacheck: globals idle (AI Task functions passed by name)
+local atk = require "ai.core.attack.util"
+
 function idle ()
    if mem.aggressive then
-      local enemy = ai.getenemy()
+      local enemy = atk.preferred_enemy()
       if enemy ~= nil and should_attack( enemy ) then
          ai.pushtask( "attack", enemy )
          return
