@@ -1,7 +1,7 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Baroncomm_baron">
-  <trigger>enter</trigger>
+  <location>enter</location>
   <chance>4</chance>
   <cond>
    not var.peek("baron_hated") and
@@ -11,10 +11,9 @@
       system.cur():faction() == faction.get("Empire") or
       system.cur():faction() == faction.get("Dvaered") or
       system.cur():faction() == faction.get("Sirius")
-   )
+   ) and
+   player.wealth() > 1e6
   </cond>
-  <flags>
-  </flags>
   <notes>
    <campaign>Baron Sauterfeldt</campaign>
    <tier>2</tier>
@@ -26,7 +25,6 @@
 --]]
 
 local hyena, hailie
--- luacheck: globals finish hail hailme (Hook functions passed by name)
 
 function create ()
     if not evt.claim(system.cur()) then
