@@ -1,11 +1,9 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Prowling baron">
-  <trigger>enter</trigger>
+  <location>enter</location>
   <chance>100</chance>
   <cond>player.misnActive("Baron") == false and player.misnActive("Prince") == false and system.cur() == system.get("Ingot")</cond>
-  <flags>
-  </flags>
   <notes>
    <campaign>Baron Sauterfeldt</campaign>
   </notes>
@@ -15,12 +13,11 @@
 -- Prowl Event for the Baron mission string. Only used when NOT doing any Baron missions.
 --]]
 
-local pnt = planet.get("Ulios")
--- luacheck: globals idle (Hook functions passed by name)
+local pnt = spob.get("Ulios")
 
 function create()
     -- TODO: Change this to the Krieger once the Baron has it. Needs "King" mission first.
-    local baronship = pilot.add( "Proteron Kahan", "Independent", pnt:pos() + vec2.new(-400,-400), _("Pinnacle"), {ai="trader"} )
+    local baronship = pilot.add( "Proteron Gauss", "Independent", pnt:pos() + vec2.new(-400,-400), _("Pinnacle"), {ai="trader"} )
     baronship:setInvincible(true)
     baronship:setFriendly()
     baronship:control()
