@@ -1,11 +1,9 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Shadowcomm2">
- <trigger>enter</trigger>
+ <location>enter</location>
  <chance>3</chance>
  <cond>system.cur():presence("hostile") &lt; 300 and player.misnDone("Shadow Vigil") and not (player.misnDone("Dark Shadow") or var.peek("darkshadow_active") == true) and system.cur():presence("Independent") &gt; 100</cond>
- <flags>
- </flags>
  <notes>
   <done_misn name="Shadow Vigil"/>
   <campaign>Shadow</campaign>
@@ -17,7 +15,6 @@
 --]]
 require "proximity"
 
--- luacheck: globals finish hailme (Hook functions passed by name)
 
 function create ()
    -- Make sure system isn't claimed, but we don't claim it
