@@ -384,6 +384,12 @@ You have {amount}. Pay {cost} for replacing {replacement} with {upgrade}?]]),
       }
 
       vn.label( s.."_yes" )
+      vn.func( function ()
+         if poi.data_get() < upgrade_cost then
+            vn.jump("special_broke")
+            return
+         end
+      end )
       mm(_([["This will take a second."
 They grab a toolbox and rush over to your boarded ship. You decide not to follow as somethings are best left not known. At least they know what they are doing right?]]))
       mm(_([[Eventually, they come back covered in what seems to be fish parts and slime.
@@ -404,13 +410,17 @@ They grab a toolbox and rush over to your boarded ship. You decide not to follow
       vn.jump("special")
    end
 
+   vn.label("special_broke")
+   mm(_([["You'll need to get some Encrypted Data Matrices first to be able to get an upgrade!"]]))
+   vn.jump("special")
+
    vn.label("special_info")
    mm(_([["Throughout my travels, I've been in many a tight spot. I remember getting stuck with a broken engine capacitor in a lost asteroid field, no food, no equipment, and a hull leaking solar radiation. It was either adapt or perish, and me being here is a testament to my ship modification skills acquired under pressure."]]))
    mm(fmt.f(_([["Or it could be the Toni's Discount Ship Repair Certification Course I did for {cost} in a back-alley on Darkshed. Still never really understood why we need to slap fish skin on the radiators. Bug juice would work much better, but anyway, I got my license and I get spruce up your ship for all your space needs!"]]),
       {cost=fmt.credits(99)}))
    mm(_([["I can offer you three different services, however, you can only have one active at a time on your ship. It is possible to change them if you wish though. In particular, I offer three services: Machiavellian Necessity, Machiavellian Fortune, and Machiavellian Virtue."]]))
    mm(_([["Machiavellian Necessity focuses on tweaking your weapon systems to be able to take decisive action when necessary."
-"Machiavellian Fortune will help you minimize the risks fickleness of fortune."
+"Machiavellian Fortune will help you minimize the risks of fickleness of fortune."
 "Finally, Machiavellian Virtue will make you a bulwark against unforeseen mishaps."]]))
    vn.jump("special")
 
