@@ -1,13 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dvaered Rehabilitation">
-  <avail>
-   <priority>10</priority>
-   <cond>faction.playerStanding("Dvaered") &lt; 0</cond>
-   <chance>100</chance>
-   <location>Computer</location>
-  </avail>
- </mission>
+ <priority>10</priority>
+ <cond>faction.playerStanding("Dvaered") &lt; 0</cond>
+ <chance>100</chance>
+ <location>Computer</location>
+</mission>
  --]]
 --[[
 --
