@@ -1,17 +1,13 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dvaered Escort">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>2</priority>
-  <chance>100</chance>
-  <location>Bar</location>
-  <faction>Dvaered</faction>
-  <done>Destroy the FLF base!</done>
-  <cond>system.get("Tarsus"):jumpDist() &lt; 4 and not (planet.cur():services().shipyard == nil)</cond>
- </avail>
+ <unique />
+ <priority>2</priority>
+ <chance>100</chance>
+ <location>Bar</location>
+ <faction>Dvaered</faction>
+ <done>Destroy the FLF base!</done>
+ <cond>system.get("Tarsus"):jumpDist() &lt; 4 and not (spob.cur():services().shipyard == nil)</cond>
  <notes>
   <campaign>Frontier Invasion</campaign>
   <requires name="The FLF is dead"/>
@@ -39,22 +35,20 @@ local fmt = require "format"
 local pir = require "common.pirate"
 
 -- Mission constants
-local destpla1, destsys1 = planet.getS("Ginni")
-local destpla2, destsys2 = planet.getS(fw.wlrd_planet)
-local destpla3, destsys3 = planet.getS("Laarss")
-local fleepla, fleesys = planet.getS("Odonga m1")
+local destpla1, destsys1 = spob.getS("Ginni")
+local destpla2, destsys2 = spob.getS(fw.wlrd_planet)
+local destpla3, destsys3 = spob.getS("Laarss")
+local fleepla, fleesys = spob.getS("Odonga m1")
 
 local ambush, hamelsen, majorTam, p, quickie, savers, warlord -- Non-persistent state
 local encounterWarlord, hamelsenAmbush, spawnTam, testPlayerSpeed -- Forward-declared functions
--- luacheck: globals ambushDied ambush_end ambush_msg attackMe enter explain_battle hamelsen_attacked land loading meeting meeting_msg1 meeting_msg2 meeting_msg3 meeting_timer moreBadGuys tamDied tamJump (Hook functions passed by name)
--- luacheck: globals discussWithTam (NPC functions passed by name)
 
 local meet_text1 = _([[After Tam boards the Goddard, you wait for about half a period until his ship undocks from the warlord's cruiser. You then receive a message from him "Everything is right, we will now land on {pnt} in order to refuel and rest for some time."]])
 
 function create()
    -- The mission should not appear just after the FLF destruction
    if not (var.peek("invasion_time") == nil or
-           time.get() >= time.fromnumber(var.peek("invasion_time")) + time.create(0, 20, 0)) then
+           time.get() >= time.fromnumber(var.peek("invasion_time")) + time.new(0, 20, 0)) then
       misn.finish(false)
    end
 
@@ -68,13 +62,13 @@ function create()
 
    misn.setNPC(_("Dvaered officer"), fw.portrait_tam, _("This Dvaered senior officer could be looking for a pilot for hire. Why else would he stay at this bar?"))
 
-   mem.previous = planet:cur()
+   mem.previous = spob.cur()
 end
 
 function accept()
    if not tk.yesno( _("In need of a pilot"), fmt.f(_([[As you approach the officer, he hails you. "Hello, citizen {player}. I was looking for you. Of course I know your name, you're one of the pilots who destroyed that damn FLF base in Sigur. Let me introduce myself: I am Major Tam, from Dvaered High Command, and more precisely from the Space Force Headquarters. I feel that you are a reliable pilot and the High Command could make more use of your services. That is why I propose to you now a simple escort mission. All that you need is a fast combat ship that can keep up with my Vendetta. What do you say?"]]), {player=player.name()}) ) then
       tk.msg(_("Too bad"), _([[Tam seems disappointed by your answer. "Well, then, maybe we will meet again later, who knows?"]]))
-      misn.finish(false)
+      return
    end
    tk.msg(_("Instructions"), fmt.f(_([[Tam seems satisfied with your answer. "I am going to pay a visit to three warlords, for military coordination reasons. They will be waiting for me in their respective Goddards in the systems {sys1}, {sys2} and {sys3}. I need you to stick to my Vendetta and engage any hostile who might try to intercept me."]]), {sys1=destsys1, sys2=destsys2, sys3=destsys3}))
 
@@ -181,7 +175,7 @@ function spawnTam( origin )
    majorTam = pilot.add( "Dvaered Vendetta", "Dvaered", origin, _("Major Tam") )
    majorTam:setHilight()
    majorTam:setVisplayer()
-   majorTam:setFaction("DHC")
+   majorTam:setFaction( fw.fct_dhc() )
 
    majorTam:outfitRm("all")
    majorTam:outfitRm("cores")
@@ -268,7 +262,7 @@ function land() -- The player is only allowed to land on special occasions
    end
    --hook.rm(mem.jumpingTam)
    mem.tamJumped = true
-   mem.previous = planet.cur()
+   mem.previous = spob.cur()
    misn.npcAdd("discussWithTam", _("Major Tam"), fw.portrait_tam, _("Major Tam is a very friendly man. At least by Dvaered military standards."))
 end
 
@@ -277,10 +271,9 @@ function loading()
 end
 
 function meeting_timer() -- Delay the triggering of the meeting
-   player.pilot():control() -- Make sure to remove the autonav
-   player.pilot():brake()
-   player.cinematics( true )
-   player.cinematics( false )
+   local pp = player.pilot()
+   pp:control() -- Make sure to remove the autonav
+   pp:brake()
 
    hook.timer(7.0, "meeting")
 end
@@ -303,7 +296,7 @@ function meeting()
       mem.stage = 3
       quickie = pilot.add( "Dvaered Vendetta", "Dvaered", destpla2 )
       quickie:cargoRm( "all" )
-      quickie:setFaction("Warlords")
+      quickie:setFaction( fw.fct_warlords() )
 
       majorTam:taskClear()
       majorTam:memory().careful = true
@@ -329,7 +322,7 @@ function attackMe()
 
    -- Change the enemies to Warlords in order to make them attack
    for i = 1,#p do
-      p[i]:setFaction("Warlords")
+      p[i]:setFaction( fw.fct_warlords() )
       p[i]:control(false)
    end
 end
@@ -337,15 +330,16 @@ end
 -- Battleaddict's bros
 function moreBadGuys()
    local buff
+   local fwarlords = fw.fct_warlords()
    for i = 1, 3 do
       buff = pilot.add( "Dvaered Ancestor", "Dvaered", destpla2 )
-      buff:setFaction("Warlords")
+      buff:setFaction(fwarlords)
    end
    buff = pilot.add( "Dvaered Vigilance", "Dvaered", destpla2, _("Colonel Hamelsen") )
-   buff:setFaction("Warlords")
+   buff:setFaction(fwarlords)
    buff = pilot.add( "Dvaered Phalanx", "Dvaered", destpla2 )
-   buff:setFaction("Warlords")
-   warlord:setFaction("Warlords")
+   buff:setFaction(fwarlords)
+   warlord:setFaction(fwarlords)
    warlord:control(false)
 end
 
@@ -353,13 +347,14 @@ end
 function hamelsenAmbush()
    local jp     = jump.get(system.cur(), mem.previous)
    local x, y, pos
+   local fwarlords = fw.fct_warlords()
    ambush = {}
    for i = 1, 3 do
       x = 1000 * rnd.rnd() + 1000
       y = 1000 * rnd.rnd() + 1000
       pos = jp:pos() + vec2.new(x,y)
 
-      ambush[i] = pilot.add( "Shark", "Warlords", pos, nil, {ai="baddie_norun"} )
+      ambush[i] = pilot.add( "Shark", fwarlords, pos, nil, {ai="baddie_norun"} )
       ambush[i]:setHostile()
       hook.pilot(ambush[i], "death", "ambushDied")
       hook.pilot(ambush[i], "land", "ambushDied")
@@ -369,7 +364,7 @@ function hamelsenAmbush()
    x = 1000 * rnd.rnd() + 2000
    y = 1000 * rnd.rnd() + 2000
    pos = jp:pos() + vec2.new(x,y)
-   hamelsen = pilot.add( "Shark", "Warlords", pos, _("Colonel Hamelsen"), {ai="baddie_norun"} )
+   hamelsen = pilot.add( "Shark", fwarlords, pos, _("Colonel Hamelsen"), {ai="baddie_norun"} )
 
    -- Nice outfits for Colonel Hamelsen (the Hellburner is her life insurance)
    hamelsen:outfitRm("all")
@@ -415,8 +410,9 @@ function ambush_msg()
    majorTam:control(false)
    hook.rm(mem.proxHook) -- To avoid triggering by mistake
 
+   local fdhc = fw.fct_dhc()
    for i, pi in ipairs(savers) do
-      pi:setFaction("DHC")
+      pi:setFaction( fdhc )
    end
 end
 
