@@ -1,17 +1,13 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dvaered Escape">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>2</priority>
-  <chance>10</chance>
-  <done>Dvaered Sabotage</done>
-  <location>Bar</location>
-  <cond>var.peek("loyal2klank") == true</cond>
-  <faction>Dvaered</faction>
- </avail>
+ <unique />
+ <priority>2</priority>
+ <chance>10</chance>
+ <done>Dvaered Sabotage</done>
+ <location>Bar</location>
+ <cond>var.peek("loyal2klank") == true</cond>
+ <faction>Dvaered</faction>
  <notes>
   <campaign>Frontier Invasion</campaign>
   <done_evt name="Betray General Klank">If you don't betray</done_evt>
@@ -32,7 +28,7 @@
    3) Goto an hospital
    4) Runaway
    5) Player has been hailed by Captain HewHew
-   6) Player has met the Empire and Pirate agent, but did not accept any of their offers
+   6) Player has met the Empire and Pirate agent, but did not accept any of their offers (yet?)
    7) Accepted Empire solution: can cross blockade of Arcturus->Goddard
    8) Accepted Pirate solution: can cross any blockade
    9) Accepted Pirate solution: can cross any blockade, but has paid cash
@@ -43,11 +39,10 @@ local portrait = require "portrait"
 local fw = require "common.frontier_war"
 local fmt = require "format"
 local pir = require "common.pirate"
+local cinema = require "cinema"
 
 local athooks, escort, hewhew, scanHooks, squad, strafer, target, zlkPilots, zlk_list -- Non-persistent state
-local rmScanHooksRaw, spawnEmpSquadron, spawnZlkSquadron -- Forward-declared functions
--- luacheck: globals backDialog convoyEnter enter escort_died escort_hailed gather hailMe killed_zlk land landBar loading rmScanHooks scanBloc spawnDrones spawnHewHew spawnStrafer straferDiscuss takeoff targetAttacked targetBoarded targetDied targetEscaped tick weNeed2land (Hook functions passed by name)
--- luacheck: globals discussHam discussNik discussStr discussThe discussTro fireSteal imperialAgent pirateDealer (NPC functions passed by name)
+local rmScanHooksRaw, spawnEmpSquadron, spawnZlkSquadron, barAgents -- Forward-declared functions
 
 escort_hailed = fw.escort_hailed -- common hooks
 
@@ -64,14 +59,14 @@ local straf_desc = _("The pilot is the only one in the group who looks like the
 -- Mission constants
 local commMass = 4
 local fzlk = faction.get("Za'lek")
-local hampla, hamsys = planet.getS("Vilati Vilata")
-local reppla, repsys = planet.getS("Dvaer Prime")
-local pripla, prisys = planet.getS("Jorla")
-local zlkpla, zlksys = planet.getS("House Za'lek Central Station")
+local hampla, hamsys = spob.getS("Vilati Vilata")
+local reppla, repsys = spob.getS("Dvaer Prime")
+local pripla, prisys = spob.getS("Jorla")
+local zlkpla, zlksys = spob.getS("House Za'lek Central Station")
 local intsys = system.get("Poltergeist")
 
 function create()
-   if planet.cur() == hampla then
+   if spob.cur() == hampla then
       misn.finish(false)
    end
 
@@ -85,7 +80,7 @@ end
 function accept()
    if not tk.yesno( _("A difficult mission"), _([[As you approach, Leblanc recognizes you. "Hello, citizen. Fancy meeting you here! The Major told me I would end up finding you by checking all the shifty places in Dvaered space. We need your services once more. But, this time, it will be sort of a bit... More illegal." You wonder how something could be more illegal than helping black ops commandos assassinate a pilot, steal a corvette, and sabotage a warlord's cruiser. And, so, you answer:]]) ) then
       tk.msg(_("Too bad"), _([["As you wish, citizen. After all, one can not obligate people to do their duty..."]]))
-      misn.finish(false)
+      return
    end
    tk.msg(_("The problem to solve"), _([["Alright," Leblanc says, "Here is the situation: before we prepare for our military operations, we need to protect our backs. Major Tam believes that the House Goddard is the key to ensure that the Empire will not thwart our plan. Tam would explain it much better than I, but as Goddard is right in between our space and Imperial space, they really have much to lose in case of a direct conflict. What is more, as we are House Goddard's best customer, they tend to appreciate us. For example, we recently paid 6M credits to repair all the electronics in Klank's and Battleaddict's Goddards.
    However, not all members of Goddard's executive board share the same opinion on our Frontier invasion projects. Mr. Danftang, their Public Relations Manager, in particular, used to see it as an opportunity to sell more cruisers to the High Command and was very favourable to the invasion. However, he was recently arrested by the Za'lek police for unclear reasons. Many suspect Goddard's shareholders of trying to settle the score. As you may have guessed at this point, our mission is to help this man escape from Za'lek prison."]]))
@@ -113,7 +108,7 @@ end
 function landBar()
 
    -- You land at the commando's planet
-   if mem.stage == 0 and planet.cur() == hampla then
+   if mem.stage == 0 and spob.cur() == hampla then
       misn.npcAdd("discussHam", _("Captain Hamfresser"), fw.portrait_hamfresser, hamfr_desc)
       misn.npcAdd("discussNik", _("Sergeant Nikolov"), fw.portrait_nikolov, nikol_desc)
       misn.npcAdd("discussTro", _("Private Tronk"), fw.portrait_tronk, tronk_desc)
@@ -137,23 +132,25 @@ function landBar()
 end
 
 function land()
-   mem.lastPlanet = planet.cur()
+   mem.lastPlanet = spob.cur()
 
    -- You land to steal a medical machine
    if mem.stage == 3 then
       misn.npcAdd("fireSteal", _("Captain Hamfresser"), fw.portrait_hamfresser, hamfr_des2)
 
    -- Land at an Imperial planet and meet the agents
-   elseif mem.stage == 5 and planet.cur():faction() == faction.get("Empire") then
+   elseif mem.stage == 5 and spob.cur():faction() == faction.get("Empire") then
       tk.msg(_("Other help offer"), fmt.f(_([[As you land, someone is waiting for you at the spaceport. "Hello, friend! Seems like you're having some trouble with the authorities out there. Looks like the Za'lek have even enlisted the help of the Imperials. There are blockades everywhere on the borders of Imperial space. Even the paths to the secret jumps are impassable. It looks like the Empire wants to catch you at all costs, but luckily enough, I have the solution. I imagine you already have a fake transponder, but they seem to have identified it.  I bet you could use a replacement. I can sell you an genuine, fake transponder fresh from the Skulls and Bones factory."
    Clearly this is a pirate looking to make a few credits off your dire situation. But, the idea is not a bad one. The Imperial ships wouldn't be looking for a ship with a Skulls and Bones fake transponder. So you ask him how many credits he wants. "{number}" is the answer. "Sounds like a lot, right? But maybe it's a bargain in exchange for your life and the success of whatever unscrupulous mission you're trying to carry out. Maybe you don't have that many credits on you right now. That's ok.  I'll accept your word to pay me at some point. Well, your word and your DNA signature. That way I can find you if you try to cheat me."
    You know that if you agree, you will have to pay, no matter what happens, otherwise you will be hounded by hit men until the end of your, probably very short, life. However, paying {credits} might allow you to avoid the otherwise messy and compromising deal you would have to make with the Imperial secret services. Meet the fake transponder dealer at the bar if interested.]]), {number=fmt.number(fw.pirate_price), credits=fmt.credits(fw.pirate_price)}))
-      mem.pirag = misn.npcAdd("pirateDealer", _("Fake transponder dealer"), portrait.get("Pirate"), _("This shifty person is for sure one of the pirates that wants to sell you a fake transponder."))
-      mem.impag = misn.npcAdd("imperialAgent", _("Feather-hat agent"), portrait.get(), _("The Imperial agent looks like a non-descript trader, as there are so many in Imperial space."))
+      barAgents()
       mem.stage = 6
 
+   elseif mem.stage == 6 and spob.cur():faction() == faction.get("Empire") then
+      barAgents()
+
    -- Land to end the mission
-   elseif mem.stage >= 4 and planet.cur() == reppla then
+   elseif mem.stage >= 4 and spob.cur() == reppla then
       tk.msg(_("Finally back"), fmt.f(_([[Upon landing, you, Hamfresser, and the VIP go to the spaceport's military office, where Major Tam is waiting for you along with a few other soldiers. He warmly greets the executive and addresses Hamfresser: "Do you know that you people scared us? We learned through diplomatic channels that you almost entirely destroyed a hospital's pharmacy, along with two police tanks and half a dozen battle androids on {pnt}. At least, apparently, you did not kill anyone. But the Za'lek were really upset".
    The captain explains: "Sir, the VIP was injured during the extraction and we needed a medical device to heal him. But once in the hospital, we were spotted by a traffic cop. Then things quickly got worse and we had to escape through the pharmacy's wall. I lost a soldier in this operation." Tam answers: "Well, you will make a detailed report later. And don't worry about the soldier, I will make sure he is replaced immediately.
    "And you, {player}, anything to report?"]]), {pnt=mem.hospPlanet, player=player.name()}))
@@ -168,16 +165,17 @@ function land()
          shiplog.append( "frontier_war", _("You helped the Dvaered High Command to liberate Mr. Danftang, public relations executive at Goddard, who was imprisoned by the Za'lek for dubious reasons. This executive is likely to help House Dvaered from a diplomatic angle. Many unexpected events happened during this operation which forced you to make a deal with the Imperial secret service.") )
       elseif mem.stage == 8 then -- Pirate debt
          tk.msg(_("Everything is almost alright"), fmt.f(_([[You explain to the major the problems you encountered. You talk about the strange deal the Empire tried to make with you. "Yes, the Imperial intelligence services are formidable. It is very hard for us to hide our intentions from them. It was right for you not to accept their offer. So, you bought a pirate fake transponder, right? I hope it was not too expensive!"
-  When you tell him the sum you had to promise to pay, Major Tam squeaks. "Whawhawhat? {price} for a fake transponder! That is not trade, it is theft!" "Well, technically..." You answer "those folks are pirates, so it's their job to rob people." The major calms down "Alright. I'll take care of the payment, so that they don't kill you, but you'll have to refund us, don't forget that! Oh, and by the way, I made sure the Za'lek don't blame you personally for what happened. They should accept you in their space now."
+  When you tell him the sum you had to promise to pay, Major Tam squeaks. "Whawhawhat? {price} for a fake transponder! That is not trade, it is theft!" "Well, technically..." You answer "those folks are pirates, so it's their job to rob people." The major calms down "Alright. I'll take care of the payment, so that they don't kill you. We will need extra fundings by the Headquarters soon, I am afraid. Oh, and by the way, I made sure the Za'lek don't blame you personally for what happened. They should accept you in their space now."
    The major starts to go away, but then comes back "Oh, I almost forgot to pay you. Hehe. Here are {credits}."]]), {price=fmt.credits(fw.pirate_price), credits=fmt.credits(fw.credits_02)}))
          var.push("dv_pirate_debt", true)
-         shiplog.append( "frontier_war", _("You helped the Dvaered High Command to liberate Mr. Danftang, public relations executive at Goddard, who was imprisoned by the Za'lek for dubious reasons. This executive is likely to help House Dvaered from a diplomatic angle. Many unexpected events happened during this operation which forced you into debt with House Dvaered. It is very likely they won't entrust you with important missions until you repay them.") )
+         shiplog.append( "frontier_war", _("You helped the Dvaered High Command to liberate Mr. Danftang, public relations executive at Goddard, who was imprisoned by the Za'lek for dubious reasons. This executive is likely to help House Dvaered from a diplomatic angle. Many unexpected events happened during this operation which forced you into debt with House Dvaered.") )
       elseif mem.stage == 9 then -- Pirate cash
          tk.msg(_("No major problem to report"), fmt.f(_([[You explain to the major the problems you encountered. You talk about the strange deal the Empire tried to make with you. "Yes, the Imperial intelligence services are formidable. It is very hard for us to hide our intentions from them. It was right for you not to accept their offer. So, you bought a pirate fake transponder, right? I hope it was not too expensive!"
-   You consider requesting to be refunded for your mission expenses, but then you remember that the Dvaered are tightfisted and violent, so you give up and simply answer: "Oh, no... not... really."
-   Tam looks satisfied, and answers: "By the way, I made sure the Za'lek don't blame you personally for what happened. They should accept you in their space now."
-   The major starts to go away, but then comes back "Oh, I almost forgot to pay you. Hehe. Here are {credits}."]]), {credits=fmt.credits(fw.credits_02)}))
+   When you tell him the sum you paid, Major Tam squeaks. "Whawhawhat? {price} for a fake transponder! That is not trade, it is theft!" "Well, technically..." You answer "those folks are pirates, so it's their job to rob people." The major calms down "Alright. I'll refund you. We will need extra fundings by the Headquarters soon, I am afraid. By the way, I made sure the Za'lek don't blame you personally for what happened. They should accept you in their space now."
+   The major starts to go away, but then comes back "Oh, I almost forgot to pay you. Hehe. Here are {credits}."]]), {price=fmt.credits(fw.pirate_price), credits=fmt.credits(fw.credits_02)}))
          shiplog.append( "frontier_war", _("You helped the Dvaered High Command to liberate Mr. Danftang, public relations executive at Goddard, who was imprisoned by the Za'lek for dubious reasons. This executive is likely to help House Dvaered from a diplomatic angle. Many unexpected events happened during this operation, that forced you to buy a fake transponder at an outrageous price.") )
+      player.pay(fw.pirate_price)
+      var.push("dv_pirate_debt", true)
       else -- Normally, the player should not achieve that (maybe with a trick I did not foresee, but it should be Xtremely hard)
          tk.msg(_("No major problem to report"), fmt.f(_([[You explain to the major the problems you encountered. You talk about the strange deal the Empire tried to make with you. "Yes, the Imperial intelligence services are formidable. It is very hard for us to hide our intentions from them. It was right for you not to accept their offer. I guess it must have been very hard, and risky, to skirt the Imperial blockade, congratulations! Oh, and by the way, I made sure the Za'lek don't blame you personally for what happened. They should accept you in their space now."
   The major starts to go away, but then comes back "Oh, I almost forgot to pay you. Hehe. Here are {credits}."]]), {credits=fmt.credits(fw.credits_02)}))
@@ -192,12 +190,12 @@ function land()
       misn.finish(true)
    end
 
-   mem.lastPla = planet.cur()
+   mem.lastPla = spob.cur()
 end
 
 -- Put the npcs back at loading
 function loading()
-   if mem.stage == 1 and planet.cur() == hampla then
+   if mem.stage == 1 and spob.cur() == hampla then
       misn.npcAdd("discussHam", _("Captain Hamfresser"), fw.portrait_hamfresser, hamfr_desc)
       misn.npcAdd("discussNik", _("Sergeant Nikolov"), fw.portrait_nikolov, nikol_desc)
       misn.npcAdd("discussTro", _("Private Tronk"), fw.portrait_tronk, tronk_desc)
@@ -207,6 +205,8 @@ function loading()
       misn.npcAdd("fireSteal", _("Captain Hamfresser"), fw.portrait_hamfresser, hamfr_des2)
    --elseif mem.stage == 4 then -- TODO: decide if we do that
       --player.takeoff()
+   elseif mem.stage == 6 and spob.cur():faction() == faction.get("Empire") then
+      barAgents()
    end
 end
 
@@ -241,7 +241,7 @@ function fireSteal()
       } )
       hook.pilot(nil, "death", "killed_zlk")
 
-      mem.hospPlanet = planet.cur()
+      mem.hospPlanet = spob.cur()
       hook.takeoff("takeoff")
       player.takeoff()
       mem.firstBloc = true
@@ -299,7 +299,7 @@ function enter()
          origin = mem.lastSys
       end
 
-      strafer = pilot.add("Vendetta", "DHC", origin, _("Lieutenant Strafer"), {ai="baddie_norun"})
+      strafer = pilot.add("Vendetta", fw.fct_dhc(), origin, _("Lieutenant Strafer"), {ai="baddie_norun"})
       strafer:setHilight()
       strafer:setVisplayer()
 
@@ -430,9 +430,10 @@ end
 function targetAttacked()
    strafer:control(false)
    hook.rm(mem.attackhook)
+   local fwarlords = fw.fct_warlords()
    for i, j in ipairs(athooks) do
       hook.rm(j)
-      escort[i]:setFaction("Warlords") -- Hack so that Strafer attacks them and not the Sting
+      escort[i]:setFaction(fwarlords) -- Hack so that Strafer attacks them and not the Sting
    end
    target:setHostile(true)
 
@@ -475,11 +476,11 @@ function weNeed2land()
    tk.msg(_("We are in trouble"), _([[When you finally jump out, Hamfresser reports: "We hit an unexpected situation back there. After we destroyed the androids and got to the jail cell, we saw that there were three other prisoners along with the target, and far more human guards than expected. They blew up our first assault bot and we had to take them down with the paralysers, but one of the prisoners grabbed a weapon and, for some reason, started to fire on us. Fortunately for me, he just pierced my lung. That is a replaceable part.
    "Then, Tronk paralysed all the prisoners and we identified and recovered the target. That's why the guy is blue, actually. But in his hurry, Tronk used the extra-strength dose. According to the medic, it is worse that we first thought. Apparently, she can keep the guy alive for a few periods, but she needs a special medical device to save him. So at our next stop, I'm afraid we will have to steal the device at the spaceport's hospital. It really annoys me as that's the kind of operation that can get ugly very quickly, especially since we're still wanted by the Za'leks, but we have no choice. I'll just be waiting for your signal at the bar next time we land.
    "If I may, I'd advise you to land somewhere within 3 periods, otherwise the VIP is likely to die. Choose a place with a shipyard and an outfitter so that you'll be able to prepare your ship in case we need to escape quickly."]]))
-   mem.timelimit = time.get() + time.create(0,3,0)
+   mem.timelimit = time.get() + time.new(0,3,0)
    misn.osdCreate(_("Dvaered Escape"), {
       fmt.f(_("Land anywhere to let Hamfresser steal a medical device. Time left: {time}"), {time=(mem.timelimit - time.get())}),
    })
-   mem.datehook = hook.date(time.create(0, 0, 100), "tick")
+   mem.datehook = hook.date(time.new(0, 0, 100), "tick")
 end
 
 function tick()
@@ -518,6 +519,21 @@ function spawnDrones()
    mem.tronkDeath = true -- This says that at next jump, Tronk will die
 end
 
+-- Spawns a group of civilian ships whose role is to discover a stealth player
+local function spawnStealthBreakers( pos )
+   local radius = 2000
+   local dist   = 1000
+   local nb     = math.ceil(2*math.pi*radius / dist)
+   local theta  = 2*math.pi/nb
+
+   local group = {}
+   for i = 1, nb do
+      group[i] = pilot.add( "Mule", "Trader", pos + vec2.newP( radius, i*theta ) )
+      group[i]:setSpeedLimit( .0001 )
+      group[i]:setFriendly( false )
+   end
+end
+
 -- Spawn blockade ships
 function spawnZlkSquadron( pos, bloc )
    squad = {}
@@ -545,6 +561,7 @@ function spawnZlkSquadron( pos, bloc )
    if mem.firstBloc then
       scanHooks[#scanHooks+1] = hook.timer(0.5, "proximityScan", {focus = squad[2], funcname = "scanBloc"})
    end
+   spawnStealthBreakers( pos )
 end
 function spawnEmpSquadron( pos, bloc )
    squad = {}
@@ -568,6 +585,7 @@ function spawnEmpSquadron( pos, bloc )
       j:setSpeedLimit( .0001 ) -- 0 disables the stuff so it's unusable
       j:setHostile(bloc)
    end
+   spawnStealthBreakers( pos )
 end
 
 -- The player sees the blocus fleet
@@ -575,10 +593,8 @@ function scanBloc()
    if mem.firstBloc then -- avoid having that happening twice in systems where there are 2 blocus
       tk.msg(_("Troubles straight ahead!"), _([[As you approach the jump point, your sensors pick up a squadron of military ships in a tight formation near the jump point. No doubt those ships are waiting for you, and it seems foolhardy to try to run the blockade.]]))
 
-      player.pilot():control()
-      player.pilot():brake() -- Normally, nobody should want to kill the player
-      player.cinematics( true )
-      camera.set( squad[1]:pos() ) -- TODO if possible: choose the right squad
+      cinema.on()
+      camera.set( squad[1]:pos(), true ) -- TODO if possible: choose the right squad
 
       rmScanHooksRaw()
       mem.firstBloc = false
@@ -588,21 +604,21 @@ end
 
 -- Strafer enters the system
 function spawnStrafer()
-   strafer = pilot.add( "Gawain", "Trader", _("Trader Gawain") )
+   strafer = pilot.add( "Gawain", "Trader", nil, _("Trader Gawain") )
    strafer:setHilight(true)
    strafer:setVisible(true)
    strafer:control(true)
    strafer:follow( player.pilot() )
-   camera.set( strafer )
+   strafer:setFriendly()
+   camera.set( strafer, true )
    mem.prox = hook.timer(0.5, "proximity", {anchor = strafer, radius = 2000, funcname = "straferDiscuss", focus = player.pilot()})
 end
 
 -- The player discuss with Strafer
 function straferDiscuss()
    hook.rm(mem.prox)
-   camera.set()
-   player.cinematics(false)
-   player.pilot():control(false)
+   cinema.off()
+   camera.set( nil, true )
 
    tk.msg(_("A friend in the dark"), fmt.f(_([[The Gawain hails you. When you respond, you hear a familiar voice. "Strafer here. I was wondering what was taking you so long. It looks like you had trouble with the Za'lek after all. There are blockades in {1}, {2}, {3} and {4}. They scan all ships. You have no chance to cross these systems alive. What did you to them to upset them like that? Anyway, I did not come empty-handed. I've have as much fuel as you want. Unfortunately, I can't board you as they would chase me as well, so I have jettisoned a few tanks at coordinates I will give to you. Just go there and scoop them. Good luck!"]]), zlk_list ) )
    strafer:control(false)  -- Strafer stops following the player
@@ -611,7 +627,7 @@ function straferDiscuss()
    local cfuel = commodity.new( N_("Fuel"), N_("Tanks of usable fuel."), {gfx_space="fuel.webp"})
    local pos = vec2.new( -1.2*system.cur():radius(), 0 )
    system.addGatherable( cfuel, 1, pos, vec2.new(0,0), 3600 ) -- Lasts for an houer
-   mem.Imark = system.mrkAdd( pos, _("FUEL") )
+   mem.Imark = system.markerAdd( pos, _("FUEL") )
    mem.gathHook = hook.gather("gather")
 end
 
@@ -625,7 +641,7 @@ function gather( comm, qtt )
    pilot.cargoRm( player.pilot(), comm, qtt )
    player.pilot():setFuel(true)
    player.msg( _("You filled your fuel tanks.") )
-   system.mrkRm(mem.Imark)
+   system.markerRm(mem.Imark)
 end
 
 -- Remove scan hooks
@@ -642,6 +658,12 @@ function rmScanHooksRaw()
    end
 end
 
+-- Put Agents at the bar when landing/loading
+function barAgents()
+   mem.pirag = misn.npcAdd("pirateDealer", _("Fake transponder dealer"), portrait.get("Pirate"), _("This shifty person is for sure one of the pirates that wants to sell you a fake transponder."))
+   mem.impag = misn.npcAdd("imperialAgent", _("Feather-hat agent"), portrait.get(), _("The Imperial agent looks like a non-descript trader, as there are so many in Imperial space."))
+end
+
 -- Spawns the odd imperial pilot
 function spawnHewHew( origin )
    hewhew = pilot.add("Hyena", "Independent", origin, _("Strange Pilot"))
@@ -689,7 +711,7 @@ function pirateDealer()
    end
 end
 function imperialAgent()
-   if tk.yesno(_("Deal with the Empire"), fmt.f(_([[As you approach, the agent seems to recognize you immediately. "Hello, {player}. I guess they told you that I may have a solution to your little... problem." You look suspiciously at the agent and ask: "What do you want in exchange?" The agent smiles: "Simple. I want to speak with the Dvaered captain. Give me 10 hecotseconds on the spacedock alone with him, not more, and the commander of the fleet in Arcturus will forget to scan your ship when you jump to Goddard."
+   if tk.yesno(_("Deal with the Empire"), fmt.f(_([[As you approach, the agent seems to recognize you immediately. "Hello, {player}. I guess they told you that I may have a solution to your little... problem." You look suspiciously at the agent and ask: "What do you want in exchange?" The agent smiles: "Simple. I want to speak with the Dvaered captain. Give me 10 hectoseconds on the spacedock alone with him, not more, and the commander of the fleet in Arcturus will forget to scan your ship when you jump to Goddard."
    This is certainly an unusual request. You think of all the state secrets a wounded Hamfresser is able to give to the Empire in 10 hectoseconds. But, Hamfresser is a professional after all, trained avoid revealing any valuable information. But, probably the Imperial agent is a professional as well, trained to recover valuable information. And the pirate proposition still holds. So you answer:]]), {player=player.name()})) then
       tk.msg(_("You made the only good choice"),_([[After accepting, you invite the agent to follow you to the dock. You enter your ship, where the commandos are waiting for you, and inform Hamfresser about the situation. He anxiously looks at the two other remaining members of his team. Nikolov grimaces and Therus nervously hits the wall. "If you think we have no other choice..." says the captain. After removing his uniform jacket (where his name and rank are written), Hamfresser takes a deep breath and joins the Imperial agent outside, in front of the ship. From a window, you see them having what looks like a peaceful conversation.
    After a while, Hamfresser returns to the ship and the agent waves to indicate that you're allowed to take off. Nikolov asks her captain: "And?" "Who knows what these Imperial weirdos wanted to know? I tried to dodge all the questions, but... well... You never know."]]))
