@@ -1,19 +1,15 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
  <mission name="Dvaered Ballet">
-  <flags>
-   <unique />
-  </flags>
-  <avail>
-   <priority>2</priority>
-   <chance>100</chance>
-   <location>None</location>
-  </avail>
-  <notes>
+ <unique />
+ <priority>2</priority>
+ <chance>100</chance>
+ <location>None</location>
+ <notes>
    <done_evt name="Strafer's Ceremony">Triggers</done_evt>
    <campaign>Frontier Invasion</campaign>
-  </notes>
- </mission>
+ </notes>
+</mission>
  --]]
 --[[
 -- Dvaered Ballet
@@ -35,7 +31,6 @@
    7) Mace Pankration performed
 --]]
 
-local atk_generic = require "ai.core.attack.generic"
 local fmt = require "format"
 local fw = require "common.frontier_war"
 require "proximity"
@@ -44,14 +39,12 @@ local portrait = require "portrait"
 -- Non-persistent state
 local annoyers, compHitHook, competitors, followers, joyyesno, leader, score_pankration, score_stadion, score_throw, targets
 local checkMace, endPankration, populate_bar, spawnCompetitors, tamStage1, tamStage2, tamStage3 -- Forward-declared functions
--- luacheck: globals compDie compHit compHitS competitorIdle dehostilify endPankrationT endStadion endThrow endTimer enter introduction land message playerHit playerHitS spawnNpcs startPankration startStadion startThrow takeoff targetHit targetIdle testEscape timerIncrement timerIncrementT (Hook functions passed by name)
--- luacheck: globals approach discussDad discussHam discussKlk discussLbl discussNkv discussPvt discussSst discussWdw tamCommon (NPC functions passed by name)
 
 -- common hooks
 message = fw.message
 
 -- Mission constants
-local destpla, destsys = planet.getS("Dvaer Prime")
+local destpla, destsys = spob.getS("Dvaer Prime")
 local radius = 4000
 local mace_fail = _("Your only weapons should be Mace rockets: land and speak again with Major Tam.")
 
@@ -76,6 +69,7 @@ function create()
    "I am Private Helmut Strafer and this is my death announcement." A strange smile appears on his face as he continues: "Yep, this is happening. It is my utmost privilege to have been killed in service to the Dvaered Nation, Great House of the Glorious Galactic Empire. You received this recording because you are on the list of people I considered to be my friends. You are invited to my funeral ceremony, which I sincerely hope you will enjoy. As I obviously don't know yet either the circumstances of my death, or the details about the ceremony, all I can do is invite you to find more information in the attached data. Now that I have merged with the void, I would be honoured if my memory helps you remain right, loyal, and strong for the rest of your own lifetime."]]), ("portraits/" .. fw.portrait_strafer) )
    if not tk.yesno( _("An invitation"), _([[You browse the attached data and find out the ceremony will take place around Dvaer Prime. As a pilot, you are invited to take part in a Mace Rocket Ballet in memory of Lieutenant Strafer, and are strongly advised to show up with a fighter and mace launchers.
    Are you going to go there?]]) ) then
+      -- TODO should probably add a timer or something or the player will get spammed every time they try to land with this
       misn.finish(false)
    end
 
@@ -189,7 +183,7 @@ local function sortPankration(i,j)
 end
 
 function spawnNpcs()
-   if (planet.cur() == destpla) then
+   if (spob.cur() == destpla) then
       -- First, compute the people's scores
       local iter = {1,2,3,4,5,6,7,8,9,10}
       table.sort( iter, sortTotal )
@@ -218,10 +212,10 @@ function spawnNpcs()
 
             if playerRank == 10 then
                tk.msg("",fmt.f(_("You receive a {1} as a reward."), {_("Dvaered Vendetta")}))
-               player.addShip("Dvaered Vendetta")
+               player.shipAdd("Dvaered Vendetta", _("You obtained this ship as a reward from Mace Rocket Ballet."))
             elseif playerRank == 9 then
                tk.msg("",fmt.f(_("You receive a {1} as a reward."), {_("Vendetta")}))
-               player.addShip("Vendetta")
+               player.shipAdd("Vendetta", _("You obtained this ship as a reward from Mace Rocket Ballet."))
             elseif playerRank == 8 then
                tk.msg("",fmt.f(_("You receive a {1} and a {2} as a reward."), {_("Tricon Zephyr II Engine"),_("Emergency Shield Booster")}))
                player.outfitAdd("Tricon Zephyr II Engine")
@@ -343,7 +337,7 @@ function tamCommon()
    end
 end
 function tamStage1()
-   tk.msg( "", _([[The first event is the "Mace Throw". There is a series of targets (old Llamas) and you have to hit them in the shortest time. The quickest pilot wins. Are you ready? Make sure you only have Unicorp Mace Launchers equipped.]]) )
+   tk.msg( "", _([[The first event is the "Mace Throw". There is a series of targets (old Llamas) and you have to hit them in the shortest time. The quickest pilot wins. Are you ready? Make sure you only have TeraCom Mace Launchers equipped.]]) )
    mem.stage = 2
 end
 function tamStage2()
@@ -351,7 +345,7 @@ function tamStage2()
    mem.stage = 4
 end
 function tamStage3()
-   tk.msg( "", fmt.f(_([[The third and last event is the "Mace Pankration". Each competitor must fight against another competitor, and disable their shields. Winners receive 7 points. Your adversary is {name}. Killing is, of course, not allowed. Are you ready? Make sure you only have Unicorp Mace Launchers equipped.]]), {name=mem.competitors_names[5]}) )
+   tk.msg( "", fmt.f(_([[The third and last event is the "Mace Pankration". Each competitor must fight against another competitor, and disable their shields. Winners receive 7 points. Your adversary is {name}. Killing is, of course, not allowed. Are you ready? Make sure you only have TeraCom Mace Launchers equipped.]]), {name=mem.competitors_names[5]}) )
    mem.stage = 6
 end
 
@@ -377,10 +371,11 @@ function takeoff()
          player.pilot():control()
          player.pilot():face(mem.center)
 
+         local fwarlords = fw.fct_warlords()
          targets = {}
          for i = 1, 30 do
             pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
-            targets[i] = pilot.add( "Llama", "Warlords", pos, _("Target "))
+            targets[i] = pilot.add( "Llama", fwarlords, pos, _("Target "))
             targets[i]:control()
             targets[i]:setHostile() -- Just in case
             pos = mem.center + vec2.newP( rnd.rnd(0,radius), rnd.angle() )
@@ -430,10 +425,11 @@ function takeoff()
          p:memory().gather_range = 4*radius
       end
 
+      local fwarlords = fw.fct_warlords()
       annoyers = {}
       for i = 1, 10 do
          pos = mem.center + vec2.newP( rnd.rnd(0,radius-500), rnd.angle() )
-         annoyers[i] = pilot.add( "Dvaered Vendetta", "Warlords", pos, _("Shooter"))
+         annoyers[i] = pilot.add( "Dvaered Vendetta", fwarlords, pos, _("Shooter"))
          fw.equipVendettaMace( annoyers[i] )
          annoyers[i]:setSpeedLimit( .0001 )
          annoyers[i]:control()
@@ -477,7 +473,7 @@ function takeoff()
          mem.playerHitHook = hook.pilot( player.pilot(), "attacked", "playerHit" )
 
          -- Mark this one as player's opponent
-         competitors[5]:setFaction("Warlords")
+         competitors[5]:setFaction( fw.fct_warlords() )
          competitors[5]:setHostile()
          competitors[5]:setHilight()
          mem.duelsEnded = 0
@@ -502,9 +498,9 @@ end
 
 -- Test wether the player only has mace rockets
 function checkMace()
-   local weap = player.pilot():outfits("weapon")
+   local weap = player.pilot():outfitsList("weapon")
    for i, w in ipairs(weap) do
-      if w ~= outfit.get("Unicorp Mace Launcher") then
+      if w ~= outfit.get("TeraCom Mace Launcher") then
          return false
       end
    end
@@ -577,7 +573,7 @@ function startPankration()
       competitors[i]:setFaction(dynFact[i])
       competitors[i]:taskClear()
       compHitHook[i] = hook.pilot( competitors[i], "attacked", "compHit" )
-      competitors[i]:memory().atk = atk_generic -- A very agressive AI
+      competitors[i]:memory().atk = nil -- Should default to generic, a very aggressive AI
    end
    for i = 1, 4 do
       competitors[i]:attack(competitors[i+5])
@@ -591,7 +587,7 @@ end
 -- One of the competitors is killed
 function compDie( _victim, attacker )
    -- This was a bad idea
-   if attacker == player.pilot() then
+   if attacker and attacker:withPlayer() then
       tk.msg( _("That was not very smart."), _([[While watching the hull of your opponent's ship collapsing under the impact of your rockets, you suddently remember with horror that this is all just a competition. You think that the Dvaered might be upset at you for this, but then you realize they will probably just kill you instead.]]) )
       faction.get("Dvaered").setPlayerStanding(-100)
       for i, p in ipairs(competitors) do
@@ -614,10 +610,11 @@ end
 
 -- Spawn Competitors
 function spawnCompetitors( )
+   local fdhc = fw.fct_dhc()
    competitors = {} -- tam, leblanc, klank, strafer, caros, micoult, johnson, ernst, guo
    for i = 1, 9 do
       local pos = mem.center + vec2.newP( radius, i*math.pi/5 - math.pi/2 )
-      competitors[i] = pilot.add( "Dvaered Vendetta", "DHC", pos, mem.competitors_names[i])
+      competitors[i] = pilot.add( "Dvaered Vendetta", fdhc, pos, mem.competitors_names[i])
       fw.equipVendettaMace( competitors[i] )
       competitors[i]:memory().Cindex = i -- Store their index
       competitors[i]:setVisible()
@@ -641,7 +638,7 @@ function targetHit( victim, attacker )
    victim:setFaction( "Independent" )
    victim:setHostile( false )
 
-   if attacker == player.pilot() then
+   if attacker and attacker:withPlayer() then
       score_throw[10] = score_throw[10] + 1
       mem.score_total[10] = mem.score_total[10] + 1
    else
@@ -691,7 +688,7 @@ end
 
 -- A competitor is hit during Stadion (problematic if the player is the agressor)
 function compHitS( _victim, attacker )
-   if attacker == player.pilot() then
+   if attacker and attacker:withPlayer() then
       tk.msg( _("This is not allowed!"), _("You are not supposed to shoot at the other competitors during the Mace Stadion. The Stadion must now be interrupted and you receive 5 penalty points. Land and speak again with Major Tam.") )
       for i, p in ipairs(competitors) do
          p:taskClear()
