@@ -1,15 +1,13 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="FLF Pirate Disturbance">
- <avail>
-  <priority>4</priority>
-  <chance>330</chance>
-  <done>Alliance of Inconvenience</done>
-  <location>Computer</location>
-  <faction>FLF</faction>
-  <faction>Frontier</faction>
-  <cond>not diff.isApplied( "flf_dead" )</cond>
- </avail>
+ <priority>4</priority>
+ <chance>330</chance>
+ <done>Alliance of Inconvenience</done>
+ <location>Computer</location>
+ <faction>FLF</faction>
+ <faction>Frontier</faction>
+ <cond>not diff.isApplied( "flf_dead" )</cond>
 </mission>
 --]]
 --[[
@@ -136,7 +134,7 @@ function accept ()
 
    mem.pirate_ships_left = 0
    mem.job_done = false
-   mem.last_system = planet.cur()
+   mem.last_system = spob.cur()
 
    hook.enter( "enter" )
    hook.jumpout( "leave" )
@@ -208,8 +206,8 @@ end
 
 function land_flf ()
    leave()
-   mem.last_system = planet.cur()
-   if planet.cur():faction() == faction.get("FLF") then
+   mem.last_system = spob.cur()
+   if spob.cur():faction() == faction.get("FLF") then
       tk.msg( "", pay_text[ rnd.rnd( 1, #pay_text ) ] )
       player.pay( mem.credits )
       faction.get("FLF"):modPlayerSingle( mem.reputation )
