@@ -1,15 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Kex's Freedom 3">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <location>Bar</location>
-  <chance>100</chance>
-  <planet>Minerva Station</planet>
-  <done>Kex's Freedom 2</done>
- </avail>
+ <unique />
+ <location>Bar</location>
+ <chance>100</chance>
+ <spob>Minerva Station</spob>
+ <done>Kex's Freedom 2</done>
  <notes>
   <campaign>Minerva</campaign>
  </notes>
@@ -21,11 +17,12 @@
    Go to planet A, get ambushed twice, and then duel in the Crimson Gauntlet.
 --]]
 local minerva  = require "common.minerva"
+local gauntlet = require "common.gauntlet"
 local pp_shaders = require 'pp_shaders'
 local vn       = require 'vn'
 local equipopt = require 'equipopt'
 local luaspfx  = require 'luaspfx'
-local fmt = require "format"
+local fmt      = require "format"
 
 -- Mission states:
 --  nil: mission not accepted yet
@@ -37,13 +34,11 @@ local fmt = require "format"
 --  5: return to Kex
 mem.misn_state = nil
 local enemies, enemies_weak, enemy_faction, noise_shader, pmalik, thug_leader, thug_pilots -- Non-persistent state
--- luacheck: globals countdown countdown_done countdown_start enter enter_the_ring generate_npc leave_the_ring maikki_arrives_extra maikki_arrives_extra_real maikki_arrives_real malik_boarded malik_death malik_disabled malik_respawn_real malik_spawn_more malik_spawn_more_real malik_speech malik_taunt player_death thug_heartbeat (Hook functions passed by name)
--- luacheck: globals approach_kex approach_malik (NPC functions passed by name)
 
 local gauntlet_start -- Forward-declared functions
 
-local targetplanet, targetsys = planet.getS("Trincea")
-local lastplanet, lastsys = planet.getS("Totoran")
+local targetplanet, targetsys = spob.getS("Trincea")
+local lastplanet, lastsys = spob.getS("Totoran")
 local gauntletsys = system.get("Crimson Gauntlet")
 
 local malik_portrait = "major_malik.webp"
@@ -88,10 +83,10 @@ end
 
 
 function generate_npc ()
-   if planet.cur() == planet.get("Minerva Station") then
+   if spob.cur() == spob.get("Minerva Station") then
       misn.npcAdd( "approach_kex", minerva.kex.name, minerva.kex.portrait, minerva.kex.description )
 
-   elseif mem.misn_state==0 and planet.cur() == targetplanet then
+   elseif mem.misn_state==0 and spob.cur() == targetplanet then
       vn.clear()
       vn.scene()
       vn.transition()
@@ -107,11 +102,11 @@ function generate_npc ()
          { fmt.f(_("Look for Major Malik at {pnt} in the {sys} system"), {pnt=lastplanet, sys=lastsys} ),
          _("Return to Kex at Minerva Station") } )
 
-   elseif (mem.misn_state==2 or mem.misn_state==3) and planet.cur() == lastplanet then
+   elseif (mem.misn_state==2 or mem.misn_state==3) and spob.cur() == lastplanet then
       mem.misn_state = 3
       misn.npcAdd( "approach_malik", _("Major Malik"), malik_portrait, _("You see Major Malik who is fairly similar to the image shown to you by Kex.") )
 
-   elseif mem.misn_state==4 and planet.cur() == lastplanet then
+   elseif mem.misn_state==4 and spob.cur() == lastplanet then
       vn.clear()
       vn.scene()
       vn.transition()
@@ -126,7 +121,7 @@ function generate_npc ()
 
       mem.misn_state = 5 -- We're done here, go back to kex:)
       misn.osdActive(2)
-      misn.markerMove( mem.misn_marker, planet.get("Minerva Station") )
+      misn.markerMove( mem.misn_marker, spob.get("Minerva Station") )
    end
 end
 
@@ -309,7 +304,7 @@ function approach_malik ()
    local malik = vn.newCharacter( _("Major Malik"), {image=malik_image} )
    vn.transition()
    vn.na(_("You approach Major Malik who seems to be enjoying a drink."))
-   malik(_([["What do you want?"]]))
+   malik(p_("Malik", [["What do you want?"]]))
    vn.na(_("You hand him the note you got from Kex. He reads it and furrows his brows a bit."))
    malik(_([["I see. You think at my age I worry about what happens to me? I've had a good career with no regrets. Your threats don't sway me."]]))
    malik(_([["However, I'm in a good mood today. How about we play a game? I have a private Crimson Gauntlet server here, let us duel in classic Dvaered fashion. If you win, I'll give you the information you want."]]))
@@ -331,7 +326,7 @@ DUEL TO THE DEATH MODE ENABLED.#0]]))
    vn.done()
 
    vn.label("decline")
-   malik(_([["OK. I'll be here if you change your mind."]]))
+   malik(p_("Malik", [["OK. I'll be here if you change your mind."]]))
    vn.run()
 
    if dogauntlet then
@@ -362,26 +357,13 @@ function enter_the_ring ()
    -- and error out because it can't teleport
    if player.isLanded() then return end
 
-   -- Teleport the player to the Crimson Gauntlet and hide the rest of the universe
-   for k,s in ipairs(system.getAll()) do
-      s:setHidden(true)
-   end
-   gauntletsys:setHidden(false)
-
-   -- Set up player stuff
-   player.pilot():setPos( vec2.new( 0, 0 ) )
-   -- Disable escorts if they exist
-   var.push("hired_escorts_disabled",true)
-   player.teleport(gauntletsys)
-   var.pop("hired_escorts_disabled")
-
-   -- Clean up
-   pilot.clear() -- Want no escorts and the likes
+   -- Enter the ring!
+   gauntlet.enter_the_ring()
 
    -- Set up Player
-   local player_vendetta = player.addShip( "Vendetta", _("Ketchup"), true )
+   local player_vendetta = player.shipAdd( "Vendetta", _("Ketchup"), _("It's virtual reality!"), true )
    mem.player_prevship = player.pilot():name() -- Ship to go back to
-   player.swapShip( player_vendetta, true )
+   player.shipSwap( player_vendetta, true )
    equipopt.generic( player.pilot(), {type_range={Afterburner={min=1}}}, "elite" )
    hook.pilot( player.pilot(), "death", "player_death" )
 
@@ -403,19 +385,11 @@ function enter_the_ring ()
 end
 -- Goes back to Totoran (landed)
 function leave_the_ring ()
-   -- Stop spfx stuff
-   luaspfx.exit()
+   gauntlet.leave_the_ring ()
 
-   -- Clear pilots so escorts get docked
-   pilot.clear()
    -- Give the player back their old ship
-   player.swapShip( mem.player_prevship, true, true )
-   -- Fix the map up
-   gauntletsys:setKnown(false)
-   for k,s in ipairs(system.getAll()) do
-      s:setHidden(false)
-   end
-   player.land( planet.get("Totoran") )
+   player.shipSwap( mem.player_prevship, true, true )
+   player.land( spob.get("Totoran") )
 end
 
 --[[
@@ -467,12 +441,10 @@ function malik_death ()
 end
 
 local function malik_respawn ()
-   luaspfx.init()
-
    enemies = {}
    enemies_weak = {}
    local pos = player.pos()
-   luaspfx.addfg( luaspfx.effects.alert{size=200}, 2.2, pos )
+   luaspfx.alert( pos, {size=200} )
    hook.timer( 2, "malik_respawn_real", pos )
 end
 function malik_respawn_real( pos )
@@ -512,7 +484,7 @@ end
 
 function malik_spawn_more ()
    local pos = player.pos() + vec2.new( 200*rnd.rnd(), 360*rnd.rnd() )
-   luaspfx.addfg( luaspfx.effects.alert{size=100}, 2.2, pos )
+   luaspfx.alert( pos, {size=100} )
    hook.timer( 2, "malik_spawn_more_real", pos )
 end
 function malik_spawn_more_real( pos )
@@ -541,7 +513,7 @@ local function maikki_arrives ()
    local pos = player.pos()
    local mc = minerva.maikkiP.colour
    local col = {mc[1], mc[2], mc[3], 0.3}
-   luaspfx.addfg( luaspfx.effects.alert{size=200, col=col}, 2.2, pos )
+   luaspfx.alert( pos, {size=200, col=col} )
    hook.timer( 2, "maikki_arrives_real", pos )
    -- Add more extras
    for i=1,4 do
@@ -586,7 +558,7 @@ function maikki_arrives_extra ()
    local mc = minerva.maikkiP.colour
    local col = {mc[1], mc[2], mc[3], 0.3}
    local pos = player.pos() + vec2.new( 200*rnd.rnd(), 360*rnd.rnd() )
-   luaspfx.addfg( luaspfx.effects.alert{size=100, col=col}, 2.2, pos )
+   luaspfx.alert( pos, {size=100, col=col} )
    hook.timer( 2, "maikki_arrives_extra_real", pos )
 end
 function maikki_arrives_extra_real( pos )
@@ -599,8 +571,7 @@ function maikki_arrives_extra_real( pos )
    p:intrinsicSet( "tur_damage", 400 )
 end
 local function malik_music ()
-   music.load('battlesomething2')
-   music.play()
+   music.play('battlesomething2.ogg')
 end
 
 function malik_speech ()
