@@ -1,27 +1,23 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="DIY Nerds">
-  <flags>
-   <unique />
-  </flags>
-  <avail>
-   <priority>4</priority>
-   <chance>2</chance>
-   <location>Bar</location>
-  </avail>
-  <notes>
-   <tier>1</tier>
-  </notes>
- </mission>
- --]]
-   --[[
-      MISSION: diy-nerds
-      DESCRIPTION: Cart some nerds and their hardware to some DIY
-      contest on a neighbouring planet. Wait until the contest is
-      over, then cart them back. Receive either your payment or
-      their hardware. The player can fail in multiple ways.
-      AUTHOR: thilo <thilo@thiloernst.de>
-   --]]
+ <unique />
+ <priority>4</priority>
+ <chance>2</chance>
+ <location>Bar</location>
+ <notes>
+  <tier>1</tier>
+ </notes>
+</mission>
+--]]
+--[[
+   MISSION: diy-nerds
+   DESCRIPTION: Cart some nerds and their hardware to some DIY
+   contest on a neighbouring planet. Wait until the contest is
+   over, then cart them back. Receive either your payment or
+   their hardware. The player can fail in multiple ways.
+   AUTHOR: thilo <thilo@thiloernst.de>
+--]]
 local pir = require "common.pirate"
 local fmt = require "format"
 
@@ -30,7 +26,6 @@ local reward = 40e3
 
 -- helper functions, defined below
 local addNerdCargo, rmNerdCargo, nerds_return, system_hasAtLeast
--- luacheck: globals nerds_bar nerds_fly1 nerds_fly2 nerds_jump nerds_land1 nerds_land2 nerds_land3 nerds_takeoff (Hook functions passed by name)
 
 -- the mission cargo
 local misn_cargo1 = N_("Group of Nerds")
@@ -44,7 +39,7 @@ local misn_cargoamount2 = 4
 local reward_outfit = "Unicorp PT-16 Core System"
 
 function create ()
-   -- the mission cannot be started with less than two landable assets in the system
+   -- the mission cannot be started with less than two landable spobs in the system
    if not system_hasAtLeast(2, "land") then
       misn.finish(false)
    end
@@ -53,10 +48,10 @@ function create ()
 end
 
 function accept ()
-   local cp = planet.cur()
+   local cp = spob.cur()
    mem.srcPlanet = cp
-   for i,p in ipairs(system.planets(system.cur())) do
-      if planet.services(p)["land"] and p ~= cp and p:canLand() then
+   for i,p in ipairs(system.spobs(system.cur())) do
+      if spob.services(p)["land"] and p ~= cp and p:canLand() then
          mem.destPlanet=p
          break -- atm, just take the first landable planet which is not the current one
       end
@@ -65,13 +60,14 @@ function accept ()
    if not tk.yesno( _("A group of excited nerds"), fmt.f(_([[As you approach the group, the babbling ceases and the papers are quickly and jealously stashed away. One of the girls comes forward and introduces herself.
     "Hi, I'm Mia. We need transportation, and you look as if you could use some dough. Interested?"
     You reply that for a deal to be worked out, they better provide some details.
-    "Listen," she says, "there's this Homebrew Processing Box Masters on {pnt}. Right over there, this system. I'm sure our box will get us the first prize. You take us there, you take us back, you get 20,000."
-    You just start to marvel at the self-assurance of one so young when she signals her impatience. "Answer me now! Will you do it?"]]), {pnt=mem.destPlanet} )) then
-      misn.finish(false)
+    "Listen," she says, "there's this Homebrew Processing Box Masters on {pnt}. Right over there, this system. I'm sure our box will get us the first prize. You take us there, you take us back, you get {creds}."
+    You just start to marvel at the self-assurance of one so young when she signals her impatience. "Answer me now! Will you do it?"]]),
+         {pnt=mem.destPlanet, creds=fmt.credits(reward)} )) then
+      return
    else
       if player.pilot():cargoFree() < 4 then
          tk.msg(_("Not enough cargo space"), _([["Aw, I forgot" she adds. "We would of course need 4 tonnes of free cargo space for our box."]]))
-         misn.finish(false)
+         return
       end
 
       misn.accept()
@@ -83,9 +79,9 @@ function accept ()
       tk.msg(_("We have a deal!"), fmt.f(_([[Upon accepting the task, you see the entire group visibly relax and you can almost feel Mia's confidence fade away - to some extent, at least. It seems that the group is quite keen on the competition, but until now had no idea how to get there.
     As the others scramble to get up from their cramped table and start to gather their belongings, it is again up to Mia to address you:
     "Really? You'll do it? Um, great. Fantastic. I just knew that, eventually, someone desperate would turn up. OK, we're set to go. We better take off immediately and go directly to {pnt}, or we'll be late for the contest!"]]), {pnt=mem.destPlanet}))
-      local distance = vec2.dist( planet.pos(mem.srcPlanet), planet.pos(mem.destPlanet) )
+      local distance = vec2.dist( spob.pos(mem.srcPlanet), spob.pos(mem.destPlanet) )
       local stuperpx = 1 / player.pilot():stats().speed_max * 30 -- from common.cargo
-      mem.expiryDate = time.get() + time.create(0, 0, 10010 + distance * stuperpx + 3300 ) -- takeoff + min travel time + leeway
+      mem.expiryDate = time.get() + time.new(0, 0, 10010 + distance * stuperpx + 3300 ) -- takeoff + min travel time + leeway
 
       addNerdCargo()
       mem.lhook = hook.land("nerds_land1", "land")
@@ -93,14 +89,14 @@ function accept ()
 	      fmt.f(_("Bring the nerds and their box to {pnt} before {time}"), {pnt=mem.destPlanet, time=time.str(mem.expiryDate, 1)}),
 	      fmt.f(_("You have {time} remaining"), {time=time.str(mem.expiryDate - time.get(), 1)}),
       })
-      mem.dhook = hook.date(time.create(0, 0, 100), "nerds_fly1")
+      mem.dhook = hook.date(time.new(0, 0, 100), "nerds_fly1")
    end
 end
 
 
 -- invoked upon landing (stage 1: cart the nerds to mem.destPlanet)
 function nerds_land1()
-   local cp = planet.cur()
+   local cp = spob.cur()
 
    if mem.intime and cp ~= mem.destPlanet then
       return
@@ -116,10 +112,10 @@ function nerds_land1()
          tk.msg(_("Happy nerds"), fmt.f(_([["Good job, {player}," Mia compliments you upon arrival. "We'll now go win the competition and celebrate a bit. You better stay in the system. We will hail you in about 4 or 5 periods, so you can pick us up an' bring us back to {pnt}."
     That said, the nerds shoulder the box and rush towards a banner which reads "Admissions".]]), {player=player.name(), pnt=mem.srcPlanet} ))
            misn.osdCreate( _("DIY Nerds"), {_("Wait several periods in this system until hailed by the nerds for their return trip")} )
-         mem.expiryDate = time.get() + time.create(0, 0, 36000+rnd.rnd(-7500,7500), 0)
+         mem.expiryDate = time.get() + time.new(0, 0, 36000+rnd.rnd(-7500,7500), 0)
          mem.hailed = false
          mem.impatient = false
-         mem.dhook = hook.date(time.create(0, 0, 100), "nerds_fly2")
+         mem.dhook = hook.date(time.new(0, 0, 100), "nerds_fly2")
          mem.lhook = hook.land("nerds_land2", "land")
          mem.jhook = hook.jumpout("nerds_jump")
 
@@ -168,7 +164,7 @@ function nerds_land2()
       return
    end
 
-   if mem.intime and planet.cur() == mem.destPlanet then
+   if mem.intime and spob.cur() == mem.destPlanet then
    -- you pickup the nerds in time
       mem.nerdswon = rnd.rnd() >= 0.6
       if mem.nerdswon then
@@ -180,7 +176,7 @@ function nerds_land2()
       end
       cleanup()
 
-         if player.pilot():cargoFree() >= 4 then
+      if player.pilot():cargoFree() >= 4 then
       -- player has enough free cargo
          nerds_return()
       else
@@ -190,7 +186,7 @@ function nerds_land2()
          mem.jhook = hook.takeoff("nerds_takeoff")
       end
 
-   elseif not mem.intime and planet.cur() == mem.destPlanet then
+   elseif not mem.intime and spob.cur() == mem.destPlanet then
    -- you're late for the pickup
       tk.msg(_("No more nerds"), fmt.f(_([[You look around, but the nerds are nowhere to be found. That is not much of a surprise, seeing that you are way too late.
     Suddenly, a guy approaches you. "Hi, are you {player}? The nerds wanted you to know that, basically, they got another transport home. One of the girls said some more, in a particularly rude language, but I don't remember the details".]]), {player=player.name()}))
@@ -215,7 +211,7 @@ function nerds_fly2()
       mem.hailed = true
    end
 
-   mem.intime = time.get() <= mem.expiryDate + time.create(0,3,3000)
+   mem.intime = time.get() <= mem.expiryDate + time.new(0,3,3000)
 
    -- no pickup since hail+2STP+1STP: mission failed (however, you must still land somewhere)
    if not mem.intime then
@@ -227,7 +223,7 @@ function nerds_fly2()
    end
 
    -- no pickup since hail+2STP
-   if mem.hailed and mem.intime and time.get() > mem.expiryDate + time.create(0,2,0) then
+   if mem.hailed and mem.intime and time.get() > mem.expiryDate + time.new(0,2,0) then
       if not mem.impatient then
          tk.msg(_("In-system communication"), _([[Your comm link comes up again. It is the nerds, whom you'd almost forgotten. You hear Mia's voice: "Hey, what are you waiting for? You'd better be here within one period, or we'll get another pilot and pay them, not you!"]]) )
          mem.impatient = true
@@ -235,7 +231,7 @@ function nerds_fly2()
         misn.osdCreate( _("DIY Nerds"), {
            fmt.f(_("Pick up the nerds on {pickup_pnt} for their return trip to {dropoff_pnt}"), {pickup_pnt=mem.destPlanet, dropoff_pnt=mem.srcPlanet}),
            _("The nerds are getting impatient"),
-           fmt.f(_("You have {time} remaining"), {time=time.str(mem.expiryDate + time.create(0,3,0) - time.get(), 2)}),
+           fmt.f(_("You have {time} remaining"), {time=time.str(mem.expiryDate + time.new(0,3,0) - time.get(), 2)}),
         })
         misn.osdActive(2)
    end
@@ -273,15 +269,17 @@ end
 function nerds_return()
    addNerdCargo()
    misn.osdCreate(_("DIY Nerds"), { fmt.f(_("Return the nerds to {pnt}"), {pnt=mem.srcPlanet} ) })
+   misn.markerMove( mem.marker, mem.srcPlanet )
    mem.lhook = hook.land("nerds_land3", "land")
 end
 
 -- hooked to 'land' in the final stage (returning the nerds)
 function nerds_land3()
-   local cp = planet.cur()
+   local cp = spob.cur()
    if cp == mem.srcPlanet then
       if mem.nerdswon then
-         tk.msg(_("The End"), fmt.f(_([[The nerds, finally exhausted from all the partying, still smile as they pack up their prize-winning box and leave your ship. Mia beams as she turns to you. "Well done, {player}. You see, since we got loads of prize money, we decided to give you a bonus. After all, we wouldn't have gotten there without your service. Here, have 30,000. Good day to you."]]), {player=player.name()}))
+         tk.msg(_("The End"), fmt.f(_([[The nerds, finally exhausted from all the partying, still smile as they pack up their prize-winning box and leave your ship. Mia beams as she turns to you. "Well done, {player}. You see, since we got loads of prize money, we decided to give you a bonus. After all, we wouldn't have gotten there without your service. Here, have {creds}. Good day to you."]]),
+            {player=player.name(), creds=fmt.credits(reward)}))
          player.pay( reward )
       else
          if not tk.yesno(_("Minor Complications"), _([[With sagging shoulders, the nerds unload their box. Mia turns to address you, not bold at all this time. "Um, we got a bit of a problem here. You know, we intended to pay the trip from our prize money. Now we don't have any prize money."
@@ -292,9 +290,9 @@ function nerds_land3()
          tk.msg(_("The End"), fmt.f( _([["You can wait for it, won't take longer than half a period," Mia informs you. You stand by as the nerds start to mod their box. As they are going about it, you wonder if they're actually wrecking it and you'll maybe be left with a piece of worthless junk.
     Finally, they set the modified box before you. "Here you are. Now you're the proud owner of the system's only home-made core system. It's a bit bulkier than we expected, with all this rigging for energy and coolant supply, but it should work just fine, about equivalent to the {outfit}. We need to go now and think about something more advanced for the next competition. Have a nice day."
     With that, the nerds leave. Having gotten nothing else out of this, you think you should visit an outfitter to see if the homemade core system may actually be of any use, or if you can at least sell it.]]), {outfit=_(reward_outfit)} ))
-         time.inc(time.create(0,0,5000))
+         time.inc(time.new(0,0,5000))
          player.outfitAdd(reward_outfit)
-         if planet.services(cp)["outfits"] then
+         if spob.services(cp)["outfits"] then
             player.landWindow("equipment")
          end
       end
@@ -304,11 +302,11 @@ function nerds_land3()
    end
 end
 
--- to check if the assets in the current system have at least _amount_ of _service_
+-- to check if the spobs in the current system have at least _amount_ of _service_
 function system_hasAtLeast (amount, service)
    local p = {}
-   for i,v in ipairs(system.planets(system.cur())) do
-      if planet.services(v)[service] and v:canLand() then
+   for i,v in ipairs(system.spobs(system.cur())) do
+      if spob.services(v)[service] and v:canLand() then
          table.insert(p,v)
       end
    end
