@@ -199,7 +199,7 @@ function create ()
 #nTarget:#0 {plt} ({shipclass}-class ship)
 #nWanted:#0 Dead or Alive
 #nLast Seen:#0 {sys} system]]),
-         {target_faction=mem.target_faction, plt=mem.name, paying_faction=mem.paying_faction, sys=mem.mysys[1], shipclass=_(ship.get(mem.aship):classDisplay())} )
+         {target_faction=mem.target_faction, plt=mem.name, paying_faction=mem.paying_faction, sys=mem.mysys[1], shipclass=_(ship.get(mem.tgtship):classDisplay())} )
    if not mem.paying_faction:static() then
       desc = desc.."\n"..fmt.f(_([[#nReputation Gained:#0 {fct}]]),
          {fct=mem.paying_faction})
