@@ -1,22 +1,17 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Pirate Hit">
- <avail>
-  <priority>3</priority>
-  <chance>1260</chance>
-  <location>Computer</location>
-  <faction>Wild Ones</faction>
-  <faction>Black Lotus</faction>
-  <faction>Raven Clan</faction>
-  <faction>Dreamer Clan</faction>
-  <faction>Pirate</faction>
-  <faction>Independent</faction>
-  <faction>FLF</faction>
-  <done>Pirate Hit Intro</done>
- </avail>
- <notes>
-  <tier>3</tier>
- </notes>
+ <priority>3</priority>
+ <chance>1260</chance>
+ <location>Computer</location>
+ <faction>Wild Ones</faction>
+ <faction>Black Lotus</faction>
+ <faction>Raven Clan</faction>
+ <faction>Dreamer Clan</faction>
+ <faction>Pirate</faction>
+ <faction>Independent</faction>
+ <faction>FLF</faction>
+ <done>Pirate Hit Intro</done>
 </mission>
 --]]
 --[[
@@ -32,23 +27,22 @@ local pilotname = require "pilotname"
 local lmisn = require "lmisn"
 
 local bounty_setup, level_setup, spawn_target, succeed -- Forward-declared functions
--- luacheck: globals jumpin jumpout pilot_attacked pilot_death pilot_jump takeoff (Hook functions passed by name)
 
 -- Mission details
 local misn_title = {}
-misn_title[1] = _("#rPIRACY:#0: Quick Assassination Job in {sys}{msg}")
-misn_title[2] = _("#rPIRACY:#0: Small Assassination Job in {sys}{msg}")
-misn_title[3] = _("#rPIRACY:#0: Moderate Assassination Job in {sys}{msg}")
-misn_title[4] = _("#rPIRACY:#0: Big Assassination Job in {sys}{msg}")
-misn_title[5] = _("#rPIRACY:#0: Dangerous Assassination Job in {sys}{msg}")
-misn_title[6] = _("#rPIRACY:#0: Highly Dangerous Assassination Job in {sys}{msg}")
+misn_title[1] = _("Quick Assassination Job in {sys}")
+misn_title[2] = _("Small Assassination Job in {sys}")
+misn_title[3] = _("Moderate Assassination Job in {sys}")
+misn_title[4] = _("Big Assassination Job in {sys}")
+misn_title[5] = _("Dangerous Assassination Job in {sys}")
+misn_title[6] = _("Highly Dangerous Assassination Job in {sys}")
 
 local hunters = {}
 local hunter_hits = {}
 
 function create ()
    -- Lower probability on non-pirate places
-   if not pir.factionIsPirate( planet.cur():faction() ) and rnd.rnd() < 0.5 then
+   if not pir.factionIsPirate( spob.cur():faction() ) and rnd.rnd() < 0.5 then
       misn.finish(false)
    end
 
@@ -86,7 +80,7 @@ function create ()
    end
 
    mem.missys = systems[ rnd.rnd( 1, #systems ) ]
-   if not misn.claim( mem.missys ) then misn.finish( false ) end
+   if not misn.claim( mem.missys, false, true ) then misn.finish( false ) end
 
    mem.target_faction = nil
    while mem.target_faction == nil and #target_factions > 0 do
@@ -106,24 +100,17 @@ function create ()
       misn.finish( false )
    end
 
-   mem.jumps_permitted = system.cur():jumpDist(mem.missys, true) + rnd.rnd( 3, 10 )
-   if rnd.rnd() < 0.05 then
-      mem.jumps_permitted = mem.jumps_permitted - 1
-   end
+   mem.jumps_permitted = system.cur():jumpDist(mem.missys, true) + rnd.rnd( 3, 8 )
 
    mem.name = pilotname.generic()
    mem.level = level_setup()
    mem.pship, mem.credits, mem.reputation = bounty_setup()
 
    -- Set mission details
-   if pir.factionIsClan( mem.paying_faction ) then
-      misn.setTitle( fmt.f( misn_title[mem.level], {sys=mem.missys, msg=fmt.f(_(" ({fct})"), {fct=mem.paying_faction} )} ) )
-   else
-      misn.setTitle( fmt.f( misn_title[mem.level], {sys=mem.missys, msg=""} ) )
-   end
+   misn.setTitle( fmt.f( pir.prefix(mem.paying_faction)..misn_title[mem.level], {sys=mem.missys} ) )
 
-   local mdesc = fmt.f( _("A meddlesome {fct} pilot known as {plt} was recently seen in the {sys} system. Local crime lords want this pilot dead. {plt} is known to be flying a {shipclass}-class ship.{msg}"), {fct=mem.target_faction, plt=mem.name, sys=mem.missys, shipclass=ship.get(mem.pship):classDisplay(), msg=faction_text } )
-   if not pir.factionIsPirate( planet.cur():faction() ) then
+   local mdesc = fmt.f( _("A meddlesome {fct} pilot known as {plt} was recently seen in the {sys} system. Local crime lords want this pilot dead. {plt} is known to be flying a {shipclass}-class ship. The pilot may disappear if you take too long to reach the {sys} system.{msg}"), {fct=_(mem.target_faction), plt=mem.name, sys=mem.missys, shipclass=_(ship.get(mem.pship):classDisplay()), msg=faction_text } )
+   if not pir.factionIsPirate( spob.cur():faction() ) then
       -- We're not on a pirate stronghold, so include a clear warning that the
       -- mission is in fact illegal.
       mdesc = mdesc .. "\n\n" .. _("#rWARNING:#0 This mission is illegal and will get you in trouble with the authorities!")
@@ -157,6 +144,19 @@ function jumpin ()
       return
    end
 
+   -- Make sure system is adjacent to the previous one (system tour)
+   local found = false
+   for k,v in ipairs(system.cur():adjacentSystems()) do
+      if v==mem.last_sys then
+         found = true
+         break
+      end
+   end
+   if not found then
+      spawn_target()
+      return
+   end
+
    local pos = jump.pos( system.cur(), mem.last_sys )
    local offset_ranges = { { -2500, -1500 }, { 1500, 2500 } }
    local xrange = offset_ranges[ rnd.rnd( 1, #offset_ranges ) ]
@@ -206,7 +206,7 @@ end
 
 
 function pilot_death( _p, attacker )
-   if attacker == player.pilot() or attacker:leader() == player.pilot() then
+   if attacker and attacker:withPlayer() then
       succeed()
    else
       local top_hunter = nil
@@ -338,7 +338,11 @@ function bounty_setup ()
          credits = 850e3 + rnd.sigma() * 100e3
          reputation = 6
       elseif mem.level == 5 then
-         pship = "Empire Hawking"
+         if rnd.rnd() < 0.5 then
+            pship = "Empire Rainmaker"
+         else
+            pship = "Empire Hawking"
+         end
          credits = 1500e3 + rnd.sigma() * 200e3
          reputation = 10
       elseif mem.level == 6 then
@@ -363,10 +367,18 @@ function bounty_setup ()
          pship = "Dvaered Vigilance"
          credits = 900e3 + rnd.sigma() * 120e3
          reputation = 6
-      elseif mem.level >= 5 then
-         pship = "Dvaered Goddard"
-         credits = 1.9e6 + rnd.sigma() * 200e3
+      elseif mem.level == 5 then
+         if rnd.rnd() < 0.5 then
+            pship = "Dvaered Arsenal"
+         else
+            pship = "Dvaered Retribution"
+         end
+         credits = 1.8e6 + rnd.sigma() * 200e3
          reputation = 10
+      elseif mem.level >= 6 then
+         pship = "Dvaered Goddard"
+         credits = 2.3e6 + rnd.sigma() * 300e3
+         reputation = 20
       end
    elseif mem.target_faction == "Soromid" then
       if mem.level == 1 then
@@ -390,7 +402,11 @@ function bounty_setup ()
          credits = 900e3 + rnd.sigma() * 120e3
          reputation = 6
       elseif mem.level == 5 then
-         pship = "Soromid Ira"
+         if rnd.rnd() < 0.5 then
+            pship = "Soromid Copia"
+         else
+            pship = "Soromid Ira"
+         end
          credits = 1.8e6 + rnd.sigma() * 200e3
          reputation = 10
       elseif mem.level == 6 then
@@ -434,11 +450,15 @@ function bounty_setup ()
          credits = 600e3 + rnd.sigma() * 80e3
          reputation = 3
       elseif mem.level == 5 then
-         pship = "Sirius Dogma"
+         pship = "Sirius Providence"
          credits = 1.5e6 + rnd.sigma() * 200e3
          reputation = 10
       elseif mem.level == 6 then
-         pship = "Sirius Divinity"
+         if rnd.rnd() < 0.5 then
+            pship = "Sirius Divinity"
+         else
+            pship = "Sirius Dogma"
+         end
          credits = 2.2e6 + rnd.sigma() * 300e3
          reputation = 20
       end
@@ -452,16 +472,16 @@ function bounty_setup ()
          credits = 900e3 + rnd.sigma() * 120e3
          reputation = 6
       elseif mem.level == 5 then
+         pship = "Za'lek Mammon"
+         credits = 1.7e6 + rnd.sigma() * 200e3
+         reputation = 10
+      elseif mem.level == 6 then
          if rnd.rnd() < 0.5 then
             pship = "Za'lek Diablo"
          else
             pship = "Za'lek Mephisto"
          end
-         credits = 1.9e6 + rnd.sigma() * 200e3
-         reputation = 10
-      elseif mem.level == 6 then
-         pship = "Za'lek Hephaestus"
-         credits = 3e6 + rnd.sigma() * 300e3
+         credits = 2e6 + rnd.sigma() * 300e3
          reputation = 20
       end
    elseif mem.target_faction == "Trader" then
@@ -481,15 +501,18 @@ function bounty_setup ()
          end
          credits = 300e3 + rnd.sigma() * 50e3
          reputation = 2
-      elseif mem.level >= 3 then
-         if rnd.rnd() < 0.5 then
-            pship = "Rhino"
-            credits = 700e3 + rnd.sigma() * 80e3
-         else
-            pship = "Mule"
-            credits = 600e3 + rnd.sigma() * 80e3
-         end
+      elseif mem.level == 3 then
+         pship = "Mule"
+         credits = 600e3 + rnd.sigma() * 80e3
          reputation = 3
+      elseif mem.level == 4 then
+         pship = "Rhino"
+         credits = 700e3 + rnd.sigma() * 80e3
+         reputation = 5
+      elseif mem.level >= 5 then
+         pship = "Zebra"
+         credits = 1e6 + rnd.sigma() * 100e3
+         reputation = 8
       end
    elseif mem.target_faction == "Traders Guild" then
       if mem.level == 1 then
@@ -508,15 +531,18 @@ function bounty_setup ()
          end
          credits = 300e3 + rnd.sigma() * 50e3
          reputation = 2
-      elseif mem.level >= 3 then
-         if rnd.rnd() < 0.5 then
-            pship = "Rhino"
-            credits = 700e3 + rnd.sigma() * 80e3
-         else
-            pship = "Mule"
-            credits = 600e3 + rnd.sigma() * 80e3
-         end
+      elseif mem.level == 3 then
+         pship = "Mule"
+         credits = 600e3 + rnd.sigma() * 80e3
          reputation = 3
+      elseif mem.level == 4 then
+         pship = "Rhino"
+         credits = 700e3 + rnd.sigma() * 80e3
+         reputation = 5
+      elseif mem.level >= 5 then
+         pship = "Zebra"
+         credits = 1e6 + rnd.sigma() * 100e3
+         reputation = 8
       end
    elseif mem.target_faction == "Independent" then
       local choices = {}
