@@ -1,14 +1,10 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Dark Shadow">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>3</priority>
-  <chance>100</chance>
-  <location>None</location>
- </avail>
+ <unique />
+ <priority>3</priority>
+ <chance>100</chance>
+ <location>None</location>
  <notes>
   <done_evt name="Shadowcomm2">Triggers</done_evt>
   <campaign>Shadow</campaign>
@@ -21,17 +17,17 @@
 local fleet = require "fleet"
 local fmt = require "format"
 local shadow = require "common.shadow"
+local cinema = require "cinema"
+local ai_setup = require "ai.core.setup"
 require "proximity"
 
 local genbu, joe, leader, leaderdest, leaderstart, seiryuu, squads -- Non-persistent state
 local spawnGenbu, spawnSquads -- Forward-declared functions
--- luacheck: globals attacked continueAmbush enter invProximity joeBoard jumpout land leaderIdle leaderVis patrolPoll playerControl seiryuuBoard showMsg showText spawnInterceptors squadVis startAmbush zoomTo (Hook functions passed by name)
--- luacheck: globals barman jorek (NPC functions passed by name)
 
 -- Mission constants
-local seirplanet, seirsys = planet.getS("Edergast")
-local jorekplanet1, joreksys1 = planet.getS("Manis")
-local jorekplanet2, joreksys2 = planet.getS("The Wringer")
+local seirplanet, seirsys = spob.getS("Edergast")
+local jorekplanet1, joreksys1 = spob.getS("Manis")
+local jorekplanet2, joreksys2 = spob.getS("The Wringer")
 local ambushsys = system.get("Herakin")
 local safesys = system.get("Eiderdown")
 
@@ -77,6 +73,7 @@ local function accept2()
    misn.setDesc(_([[You have been tasked by Captain Rebina of the Four Winds to assist Jorek McArthy.]]))
    misn.setReward(_("A sum of money."))
    mem.landhook = hook.land("land")
+   mem.loadhook = hook.load("spobNpcs") -- Ensure NPCs appear at loading
    mem.jumpouthook = hook.jumpout("jumpout")
 end
 
@@ -87,13 +84,13 @@ function seiryuuBoard()
    player.unboard()
    if mem.stage == 1 then -- Briefing
       tk.msg(_("Disclosure"), fmt.f(_([[You make your way through the now familiar corridors of the Seiryuu. You barely notice the strange environment anymore. It seems unimportant compared to the strange events that surround your every encounter with these Four Winds.
-    You step onto the bridge, where Captain Rebina is waiting for you. "Welcome back, {player}," she says. "I'm pleased to see that you decided to respond to our communication. I doubt you would have come here if you weren't willing to continue to aid us. Your presence here confirms that you are a reliable partner, so I will treat you accordingly."
-    The captain motions you to take a seat at what looks like a holotable in the centre of the bridge. "Before I tell you what I've called you here for, I feel I should explain to you in full who we are, what we do and what your part in all this is." She takes a seat opposite from yours, and leans on the holotable. "As I've said before, we are the Four Winds. Our organization is a very secretive one, as you've experienced firsthand. Very few outside our ranks know of our existence, and now you're one of those few."]]), {player=player.name()}))
-      tk.msg(_("Disclosure"), fmt.f(_([["The Four Winds are old, {player}. Very old indeed. The movement dates back to old Earth, before the Space Age, even. We have been with human civilization throughout the ages, at first only in the Eastern nations, later establishing a foothold worldwide. Our purpose was to guide humanity, prevent it from making mistakes it could not afford to make. We never came out in the open, we always worked behind the scenes, from the shadows. We were diplomats, scientists, journalists, politicians' spouses, sometimes even assassins. We used any means necessary to gather information and avert disaster, when we could.
+    You step onto the bridge where Captain Rebina is waiting for you. "Welcome back, {player}," she says. "I'm pleased to see that you decided to respond to our communication. I doubt you would have come here if you weren't willing to continue to aid us. Your presence here confirms that you are a reliable partner, so I will treat you accordingly."
+    The captain motions you to take a seat at what looks like a holotable in the centre of the bridge. "Before I tell you what I've called you here for, I feel I should explain to you in full who we are, what we do, and what your part in all this is." She takes a seat opposite from yours, and leans on the holotable. "As I've said before, we are the Four Winds. Our organization is a very secretive one, as you've experienced firsthand. Very few outside our ranks know of our existence, and now you're one of those few."]]), {player=player.name()}))
+      tk.msg(_("Disclosure"), fmt.f(_([["The Four Winds are old, {player}. Very old indeed. The movement dates back to old Earth, before the Space Age, even. We have been with human civilization throughout the ages, at first only in the Eastern nations, later establishing a foothold worldwide. Our purpose was to guide humanity and prevent it from making mistakes it could not afford to make. We never came out in the open, we always worked behind the scenes, from the shadows. We were diplomats, scientists, journalists, politicians' spouses, sometimes even assassins. We used any means necessary to gather information and avert disaster, when we could.
     "Of course, we didn't always succeed. We couldn't prevent the nuclear strikes on Japan, though we managed to prevent several others. We foiled the sabotage attempts on several of the colony ships launched during the First Growth, but sadly failed to do so in Maelstrom's case. We failed to stop the Faction Wars, though we managed to help the Empire gain the upper hand. Our most recent failure is the Incident - we should have seen it coming, but we were completely taken by surprise."]]), {player=player.name()}))
       shadow.addLog( fmt.f(_([[Captain Rebina has further explained the organization she works for.
     "As I've said before, we are the Four Winds. Our organization is a very secretive one, as you've experienced firsthand. Very few outside our ranks know of our existence, and now you're one of those few.
-    "The Four Winds are old, {player}. Very old indeed. The movement dates back to old Earth, before the Space Age, even. We have been with human civilization throughout the ages, at first only in the Eastern nations, later establishing a foothold worldwide. Our purpose was to guide humanity, prevent it from making mistakes it could not afford to make. We never came out in the open, we always worked behind the scenes, from the shadows. We were diplomats, scientists, journalists, politicians' spouses, sometimes even assassins. We used any means necessary to gather information and avert disaster, when we could.
+    "The Four Winds are old, {player}. Very old indeed. The movement dates back to old Earth, before the Space Age, even. We have been with human civilization throughout the ages, at first only in the Eastern nations, later establishing a foothold worldwide. Our purpose was to guide humanity and prevent it from making mistakes it could not afford to make. We never came out in the open, we always worked behind the scenes, from the shadows. We were diplomats, scientists, journalists, politicians' spouses, sometimes even assassins. We used any means necessary to gather information and avert disaster, when we could.
     "Of course, we didn't always succeed. We couldn't prevent the nuclear strikes on Japan, though we managed to prevent several others. We foiled the sabotage attempts on several of the colony ships launched during the First Growth, but sadly failed to do so in Maelstrom's case. We failed to stop the Faction Wars, though we managed to help the Empire gain the upper hand. Our most recent failure is the Incident - we should have seen it coming, but we were completely taken by surprise."]]), {player=player.name()} ) )
       tk.msg(_("Disclosure"), _([[Captain Rebina sits back in her chair and heaves a sigh. "I think that may have been when things started to change. We used to be committed to our purpose, but apparently things are different now. No doubt you remember what happened to the diplomatic exchange between the Empire and the Dvaered some time ago. Well, suffice to say that increasing the tension between the two is definitely not part of our mandate. In fact, it's completely at odds with what we stand for. And that was not just an isolated incident either. Things have been happening that suggest Four Winds involvement, things that bode ill."
     She activates the holotable, and it displays four cruisers, all seemingly identical to the Seiryuu, though you notice subtle differences in the hull designs.
@@ -143,7 +140,7 @@ end
 -- Enter hook
 function enter()
    if system.cur() == seirsys then
-      seiryuu = pilot.add( "Pirate Kestrel", "Four Winds", vec2.new(300, 300) + seirplanet:pos(), _("Seiryuu"), {ai="trader"} )
+      seiryuu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), vec2.new(300, 300) + seirplanet:pos(), _("Seiryuu"), {ai="trader"} )
       seiryuu:setInvincible(true)
       seiryuu:control()
       if mem.stage == 1 or mem.stage == 6 then
@@ -162,7 +159,7 @@ function enter()
       pilot.toggleSpawn(false)
       player.allowLand(false, _("Landing permission denied. Our docking clamps are currently undergoing maintenance."))
       -- Meet Joe, our informant.
-      joe = pilot.add( "Vendetta", "Four Winds", vec2.new(-500, -4000), _("Four Winds Informant"), {ai="trader"} )
+      joe = pilot.add( "Vendetta", shadow.fct_fourwinds(), vec2.new(-500, -4000), _("Four Winds Informant"), {ai="trader"} )
       joe:control()
       joe:setHilight(true)
       joe:setVisplayer()
@@ -249,11 +246,12 @@ function spawnSquads(highlight)
    leader = {}
 
    for i, start in ipairs(leaderstart) do
-      squads[i] = fleet.add( 4, "Vendetta", "Rogue Four Winds", leaderstart[i], _("Four Winds Patrol") )
+      squads[i] = fleet.add( 4, "Vendetta", shadow.fct_rogues(), leaderstart[i], _("Four Winds Patrol") )
       for j, k in ipairs(squads[i]) do
          hook.pilot(k, "attacked", "attacked")
          k:outfitRm("all")
          k:outfitAdd("Cheater's Laser Cannon", 6) -- Equip these fellas with unfair weaponry
+         ai_setup.setup(k)
          k:setNoDisable()
       end
       squads[i][1]:control() -- Only need to control leader. Others will follow
@@ -329,10 +327,11 @@ end
 
 -- Spawns the Genbu
 function spawnGenbu(sys)
-   genbu = pilot.add( "Pirate Kestrel", "Four Winds", sys, _("Genbu") )
+   genbu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), sys, _("Genbu") )
    genbu:outfitRm("all")
    genbu:outfitAdd("Heavy Laser Turret", 3)
    genbu:outfitAdd("Cheater's Ragnarok Beam", 3) -- You can't win. Seriously.
+   ai_setup.setup(genbu)
    genbu:control()
    genbu:setHilight()
    genbu:setVisplayer()
@@ -369,12 +368,13 @@ end
 
 -- Spawns a wing of Lancelots that intercept the player.
 function spawnInterceptors()
-   local inters = fleet.add( 3, "Lancelot", "Rogue Four Winds", genbu:pos(), _("Four Winds Lancelot") )
+   local inters = fleet.add( 3, "Lancelot", shadow.fct_rogues(), genbu:pos(), _("Four Winds Lancelot") )
    for _, j in ipairs(inters) do
       j:outfitRm("all")
       j:outfitAdd("Cheater's Laser Cannon", 4) -- Equip these fellas with unfair weaponry
       j:outfitAdd("Engine Reroute", 1)
       j:outfitAdd("Improved Stabilizer", 1)
+      ai_setup.setup(j)
       j:setLeader( genbu )
       j:control()
       j:attack(player.pilot())
@@ -387,11 +387,18 @@ end
 
 -- Land hook
 function land()
-   if planet.cur() == jorekplanet1 and mem.stage == 2 then
+   if spob.cur() == jorekplanet1 and mem.stage == 2 then
       -- Thank you player, but our SHITMAN is in another castle.
       tk.msg(_("No Jorek"), _([[You step into the bar, expecting to find Jorek McArthy sitting somewhere at a table. However, you don't see him anywhere. You decide to go for a drink to contemplate your next move. Then, you notice the barman is giving you a curious look.]]))
+   end
+   spobNpcs()
+end
+
+-- Get the NPCs to appear
+function spobNpcs()
+   if spob.cur() == jorekplanet1 and mem.stage == 2 then
       mem.barmanNPC = misn.npcAdd("barman", _("Barman"), "neutral/barman.webp", _("The barman seems to be eyeing you in particular."), 4)
-   elseif planet.cur() == jorekplanet2 and mem.stage == 3 then
+   elseif spob.cur() == jorekplanet2 and mem.stage == 3 then
       mem.joreknpc = misn.npcAdd("jorek", _("Jorek"), "neutral/unique/jorek.webp", _("There he is, Jorek McArthy, the man you've been chasing across half the galaxy. What he's doing on this piece of junk is unclear."), 4)
    end
 end
@@ -404,7 +411,7 @@ function barman()
     "Well, your description was given to me by an old friend of mine. His name is Jarek. Do you know him?"
     You tell him that you don't know anyone by the name of Jarek, but you do know a man named Jorek. The barman visibly relaxes when he hears that name.
     "Ah, good. You're the real deal then. Can't be too careful in times like these, you know. Anyway, old Jorek was here, but he couldn't stay. He told me to keep an eye out for you, said you'd be coming to look for him." The barman glances around to make sure nobody is within earshot, even though the bar's music makes it difficult to overhear anyone who isn't standing right next to you. "I have a message for you. Go to the {sys} system and land on {pnt}. Jorek will be waiting for you there. But you better be ready for some trouble. I don't know what kind of trouble it is, but Jorek is never in any kind of minor trouble. Don't say I didn't warn you."
-    You thank the barman, pay for your drink and prepare to head back to your ship, wondering whether your armaments will be enough to deal with whatever trouble Jorek is in.]]), {player=player.name(), sys=joreksys2, pnt=jorekplanet2}))
+    You thank the barman, pay for your drink, and prepare to head back to your ship, wondering whether your armaments will be enough to deal with whatever trouble Jorek is in.]]), {player=player.name(), sys=joreksys2, pnt=jorekplanet2}))
    dest_updated(jorekplanet2, joreksys2)
    misn.npcRm(mem.barmanNPC)
    mem.stage = 3
@@ -435,7 +442,7 @@ end
 
 -- Capsule function for camera.set, for timer use
 function zoomTo(target)
-   camera.set(target, true, mem.zoomspeed)
+   camera.set(target, false, mem.zoomspeed)
 end
 
 -- Capsule function for player.msg, for timer use
@@ -451,14 +458,16 @@ end
 -- Capsule function for player.pilot():control(), for timer use
 -- Also saves the player's velocity.
 local pvel
-function playerControl(status)
-   player.pilot():control(status)
-   player.cinematics(status)
+function playerControl( status )
+   local pp = player.pilot()
    if status then
-      pvel = player.pilot():vel()
-      player.pilot():setVel(vec2.new(0, 0))
+      cinema.on()
+      pp:control(false)
+      pvel = pp:vel()
+      pp:setVel(vec2.new(0, 0))
    else
-      player.pilot():setVel(pvel)
+      cinema.off()
+      pp:setVel(pvel)
    end
 end
 
