@@ -1,15 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Shadowrun">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>3</priority>
-  <chance>20</chance>
-  <location>Bar</location>
-  <cond>system.get("Klantar"):jumpDist() &lt; 3</cond>
- </avail>
+ <unique />
+ <priority>3</priority>
+ <chance>20</chance>
+ <location>Bar</location>
+ <cond>system.get("Klantar"):jumpDist() &lt; 3</cond>
  <notes>
   <campaign>Shadow</campaign>
  </notes>
@@ -27,14 +23,12 @@ local fleet = require "fleet"
 local fmt = require "format"
 local shadow = require "common.shadow"
 
-local pnt, sys = planet.getS("Durea") -- Where SHITMAN lives
+local pnt, sys = spob.getS("Durea") -- Where SHITMAN lives
 local sys2 = system.get("Uhriabi") -- The system where the ship is
 local shipname = _("Seiryuu")
 
 local seiryuu -- Non-persistent state
 local dateresolution -- Forward-declared functions
--- luacheck: globals abort board date enter land (Hook functions passed by name)
--- luacheck: globals jorek officer soldier1 soldier2 (NPC functions passed by name)
 
 function create ()
    if not misn.claim( {sys, sys2} ) then
@@ -54,10 +48,10 @@ function accept()
       tk.msg(_("A dark-haired woman"), _([[Rebina nods at you to acknowledge your existence. "We meet again. I'm glad to see you've not gotten yourself killed yet." She smiles meaningfully. "As it happens I haven't found anyone to take care of my business yet. Perhaps you would reconsider? Allow me to remind you what this is about."]]))
    else
       tk.msg(_("A dark-haired woman"), _([[The woman calmly watches you as you approach her, seemingly not at all surprised to see you. Clad in a plain yet expensive-looking black dress and sipping from her martini, she emits an aura of class that is almost intimidating.
-    "Hello," she greets you. "I had a feeling you might want to talk to me. You are different from most..." she gestures at the other patrons of the bar, "And so am I. But where are my manners, I haven't introduced myself. My name is Rebina. I am what you might call a talent hunter. I visit places such as these to find people of exceptional talent. People such as you."
+    "Hello," she greets you. "I had a feeling you might want to talk to me. You are different from most..." she gestures at the other patrons of the bar, "And so am I. But where are my manners, I haven't introduced myself. My name is Rebina. I am what you might call a talent hunter. I visit places such as these to find people of exceptional skill. People such as you."
     You begin to introduce yourself, but Rebina waves it away, perhaps because your name doesn't interest her, or possibly because she already knows who you are. "Let's not waste words on idle formalities," she says. "I am here to talk business, and I've got a proposition for you, if you're interested."]]))
    end
-   if tk.yesno(_("Rebina's proposition"), _([["What I need is a pilot and a ship. Specifically, I need a skilled pilot and a capable ship. Do you fit that description? I have a feeling you do. You see, what I am about to suggest you do is both profitable and dangerous." Rebina takes another sip of her drink before continuing, allowing what she just said to fully register. "I will not lie to you. There are... rivalries out there, and working for me will mean you'll take sides in some of them. People will take notice of you, and some of them will try to kill you."
+   if tk.yesno(_("Rebina's proposition"), _([["What I need is a pilot and a ship. Specifically, I need a skilled pilot and a capable ship. Do you fit that description? I have a feeling you do. You see, what I am about to propose to you is both profitable and dangerous." Rebina takes another sip of her drink before continuing, allowing what she just said to fully register. "I will not lie to you. There are... rivalries out there, and working for me will mean you'll take sides in some of them. People will take notice of you, and some of them will try to kill you."
     You explain that taking risks comes with being an independent pilot and that you took the captain's chair with appropriate resolve, but Rebina pins you with a piercing gaze. "These are no ordinary pirate raids we're talking about," she admonishes you. "If you take this assignment, you will be a painted target. I want you to be well aware of this." There is another pause, but then she continues in a milder tone of voice. "That being said, I can assure you that the reward is well worth the risk. Pull this off, and you'll walk away considerably richer than you were."
     Rebina leans back, levelly meeting your gaze. "That's all I can tell you at this point. You'll get more details only once you accept this job. If you accept this job. What say you?"]])) then
       misn.accept()
@@ -68,13 +62,13 @@ function accept()
 
       -- Translator note: If the plural forms are a problem, assume the numbers here are 20 and 50.
       tk.msg(_("Rebina's explanation"), fmt.f(_([["You know what to do," Rebina tells you. "You will find Jorek in the spaceport bar on {pnt}. When you see him, tell him you've come to 'see to his special needs'. Oh, and please be discreet. Don't talk about things you don't need to; the walls have ears in that place. In particular, don't mention any names."
-    "You will be on a time schedule. You must meet Jorek within {t1} periods, or he will assume you are not coming and go back into hiding. You must also be at the meeting point {t2} periods from now. If you fail to meet with Jorek within the time limit or if you are prevented from taking him offworld for any other reason, make your way to the {plt} and report what happened. We'll take it from there. If you fail to show up at the designated time, we will assume you have failed, and the {plt} will leave."
+    "You will be on a time schedule. You must meet Jorek within {t1} periods, or he will assume you are not coming and go back into hiding. You must also be at the meeting point {t2} periods from now. If you fail to meet with Jorek within the time limit or if you are prevented from taking him off-world for any other reason, make your way to the {plt} and report what happened. We'll take it from there. If you fail to show up at the designated time, we will assume you have failed, and the {plt} will leave."
     Rebina empties her glass and places it on the bar before rising to her feet. "That will be all. Good luck, and keep your wits about you."
     Then Rebina takes her leave from you and gracefully departs the spaceport bar. You order yourself another drink. You've got the feeling you're going to need it.]]), {pnt=pnt, t1=mem.timelimit1, t2=mem.timelimit2, plt=shipname}))
 
       -- Set deadlines
-      mem.deadline1 = time.get() + time.create(0, mem.timelimit1, 0)
-      mem.deadline2 = time.get() + time.create(0, mem.timelimit2, 0)
+      mem.deadline1 = time.get() + time.new(0, mem.timelimit1, 0)
+      mem.deadline2 = time.get() + time.new(0, mem.timelimit2, 0)
 
       misn.setTitle(_("Shadowrun"))
       misn.setReward(_("You were promised riches..."))
@@ -87,19 +81,19 @@ function accept()
       mem.shadowrun = 2
 
       mem.dateres = 500
-      mem.datehook = hook.date(time.create(0, 0, mem.dateres), "date")
+      mem.datehook = hook.date(time.new(0, 0, mem.dateres), "date")
       hook.land("land")
       hook.enter("enter")
    else
       tk.msg(_("A dark-haired woman"), _([["I see. What a shame." Rebina's demeanor conveys that she's disappointed but not upset. "I can understand your decision. One should not bite off more than one can chew, after all. It seems I will have to try to find another candidate." She tilts her head slightly. Then, "Although if you change your mind before I do, you're welcome to seek me out again. I'll be around."
-    Rebina finishes her drink and gets up. Then, with a cordial wave of her hand she sweeps out of the door. You momentarily regret not taking her up on her offer, but it passes. You've made the right decision, and that is that.]]))
+    Rebina finishes her drink and gets up. Then, with a cordial wave of her, hand she sweeps out of the door. You momentarily regret not taking her up on her offer, but it passes. You've made the right decision, and that is that.]]))
       var.push("shadowrun", 1) -- For future appearances of this mission
       misn.finish(false)
    end
 end
 
 function land()
-   local landed = planet.cur()
+   local landed = spob.cur()
    if pnt == landed then
       misn.npcAdd( "jorek", _("An unpleasant man."), "neutral/unique/jorek.webp", _("A middle-aged, cranky looking man is sitting at a table by himself. You are fairly certain that this is the fellow you're looking for.") )
       misn.npcAdd( "officer", _("Officer at the bar"), portrait.getMaleMil("Empire"), _("You see a military officer with a drink at the bar. He doesn't seem to be very interested in it, though...") )
@@ -164,18 +158,18 @@ function date()
 end
 
 function dateresolution(time)
-   if time - time.get() < time.create(0, 0, 5000) and mem.dateres > 30 then
+   if time - time.get() < time.new(0, 0, 5000) and mem.dateres > 30 then
       mem.dateres = 30
       hook.rm(mem.datehook)
-      mem.datehook = hook.date(time.create(0, 0, mem.dateres), "date")
-   elseif time - time.get() < time.create(0, 1, 0) and mem.dateres > 100 then
+      mem.datehook = hook.date(time.new(0, 0, mem.dateres), "date")
+   elseif time - time.get() < time.new(0, 1, 0) and mem.dateres > 100 then
       mem.dateres = 100
       hook.rm(mem.datehook)
-      mem.datehook = hook.date(time.create(0, 0, mem.dateres), "date")
-   elseif time - time.get() >= time.create(0, 1, 0) and mem.dateres < 500 then
+      mem.datehook = hook.date(time.new(0, 0, mem.dateres), "date")
+   elseif time - time.get() >= time.new(0, 1, 0) and mem.dateres < 500 then
       mem.dateres = 500
       hook.rm(mem.datehook)
-      mem.datehook = hook.date(time.create(0, 0, mem.dateres), "date")
+      mem.datehook = hook.date(time.new(0, 0, mem.dateres), "date")
    end
 end
 
@@ -212,7 +206,7 @@ function enter()
    -- Handle the Seiryuu, the last stop on this mission
    if mem.shadowrun >= 2 and system.cur() == sys2 then
       local mypos = vec2.new(-1500, 600)
-      seiryuu = pilot.add( "Pirate Kestrel", "Four Winds", mypos , _("Seiryuu"), {ai="trader"} )
+      seiryuu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), mypos , _("Seiryuu"), {ai="trader"} )
 
       seiryuu:setActiveBoard(true)
       seiryuu:control()
