@@ -1,23 +1,20 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Helping Nelly Out 1">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <priority>1</priority>
-  <chance>100</chance>
-  <cond>require("common.pirate").systemPresence() &lt;= 0 and not player.misnActive("Tutorial")</cond>
-  <location>Bar</location>
-  <faction>Dvaered</faction>
-  <faction>Empire</faction>
-  <faction>Frontier</faction>
-  <faction>Goddard</faction>
-  <faction>Independent</faction>
-  <faction>Sirius</faction>
-  <faction>Soromid</faction>
-  <faction>Za'lek</faction>
- </avail>
+ <unique />
+ <priority>1</priority>
+ <chance>100</chance>
+ <cond>require("common.pirate").systemPresence() &lt;= 0 and not player.misnActive("Tutorial")</cond>
+ <location>Bar</location>
+ <faction>Dvaered</faction>
+ <faction>Empire</faction>
+ <faction>Frontier</faction>
+ <faction>Goddard</faction>
+ <faction>Independent</faction>
+ <faction>Sirius</faction>
+ <faction>Soromid</faction>
+ <faction>Za'lek</faction>
+  <chapter>[01]</chapter>
  <notes>
   <campaign>Tutorial Nelly</campaign>
  </notes>
@@ -61,7 +58,6 @@ local lmisn = require "lmisn"
 --]]
 mem.misn_state = nil
 local derelict -- Non-persistent state
--- luacheck: globals board clear_target_hyperspace enter equip equipment info info_cargo info_mission info_reminder info_ship info_shiplog info_standing info_weapons land outfit_buy outfits talk_derelict target_hyperspace (Hook functions passed by name)
 
 -- Constants
 local cargo_type  = commodity.get("Food")
@@ -71,8 +67,8 @@ local outfit_tobuy = outfit.get("Ion Cannon") -- If changed, references to ion c
 
 function create ()
    -- Save current system to return to
-   mem.retpnt, mem.retsys = planet.cur()
-   if not misn.claim( mem.retsys ) then
+   mem.retpnt, mem.retsys = spob.cur()
+   if not misn.claim( {mem.retsys, "nelly"} ) then
       misn.finish()
    end
    -- Need commodity exchange and mission computer
@@ -99,7 +95,7 @@ function create ()
       end
       return false
    end
-   mem.destpnt, mem.destsys = lmisn.getRandomPlanetAtDistance( system.cur(), 1, 1, "Independent", false, pntfilter )
+   mem.destpnt, mem.destsys = lmisn.getRandomSpobAtDistance( system.cur(), 1, 1, "Independent", false, pntfilter )
    if not mem.destpnt then
       misn.finish()
    end
@@ -119,9 +115,15 @@ function accept ()
    local nel = vn.newCharacter( tutnel.vn_nelly() )
    vn.transition( tutnel.nelly.transition )
 
-   nel(fmt.f(_([[The lone individual lightens up when you near.
+   if var.peek("nelly_met") then
+      nel(fmt.f(_([[Nelly lightens up when you near her.
+"Hello again! I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
+         {cargo=cargo_type, pnt=mem.destpnt, sys=mem.destsys}))
+   else
+      nel(fmt.f(_([[The lone individual lightens up when you near her.
 "Say, you look like a pilot with a working ship. I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
-      {cargo=cargo_type, pnt=mem.destpnt, sys=mem.destsys}))
+         {cargo=cargo_type, pnt=mem.destpnt, sys=mem.destsys}))
+   end
 
    vn.menu{
       {_("Help them out"), "accept"},
@@ -146,22 +148,28 @@ function accept ()
       end
       doaccept = true
    end )
-   nel(_([["Great! My name is Nelly. Glad to make your acquaintance. I'll have the dock workers load up your ship and we can be off. This should be a piece of cake."
-They cock their head a bit at you.
-"Say, you wouldn't happen to be a novice pilot?"]]))
-   vn.menu{
-      {_([["Yes"]]), "novice_yes"},
-      {_([["No"]]), "novice_no"},
-   }
+   if var.peek("nelly_met") then
+      nel(_([["Great! I'll have the dock workers load up your ship and we can be off. This should be a piece of cake."]]))
+   else
+      nel(_([["Great! My name is Nelly. Glad to make your acquaintance. I'll have the dock workers load up your ship and we can be off. This should be a piece of cake."
+   They cock their head a bit at you.
+   "Say, you wouldn't happen to be a novice pilot?"]]))
+      vn.func( function ()
+         var.push( "nelly_met", true )
+      end )
+      vn.menu{
+         {_([["Yes"]]), "novice_yes"},
+         {_([["No"]]), "novice_no"},
+      }
 
-   vn.label("novice_yes")
-   nel(fmt.f(_([["I knew it! You seem to have a nice fresh aura around you. Reminds me of back in the day when I was starting out. Starting out can be a bit tricky, so I hope you don't mind if I give you some advice on the road."
-"For starters, if you haven't already, you should buy a #oLocal Map#0 that will help you get the directions to {sys}. You can buy it at the main landing window or the outfiting window. Anyway, Let's get going!"]]), {sys=mem.destsys}))
-   vn.done( tutnel.nelly.transition )
-
-   vn.label("novice_no")
-   nel(_([["Weird. I could have sworn you had some sort of new pilot aura around you. Must have been my imagination. Let's get going!"]]))
+      vn.label("novice_yes")
+      nel(fmt.f(_([["I knew it! You seem to have a nice fresh aura around you. Reminds me of back in the day when I was starting out. Starting out can be a bit tricky, so I hope you don't mind if I give you some advice on the road."
+   "For starters, if you haven't already, you should buy a #oLocal Map#0 that will help you get the directions to {sys}. You can buy it at the main landing window or the outfiting window. Anyway, Let's get going!"]]), {sys=mem.destsys}))
+      vn.done( tutnel.nelly.transition )
 
+      vn.label("novice_no")
+      nel(_([["Weird. I could have sworn you had some sort of new pilot aura around you. Must have been my imagination. Let's get going!"]]))
+   end
    vn.done( tutnel.nelly.transition )
    vn.run()
 
@@ -191,7 +199,7 @@ function land ()
       mem.hk_info_timer = nil
    end
 
-   local pcur = planet.cur()
+   local pcur = spob.cur()
    if mem.misn_state==1 and pcur == mem.destpnt then
       local wanthelp = true
 
@@ -360,7 +368,7 @@ function board ()
 end
 
 function info_reminder ()
-   player.pilot():comm(fmt.f(_([[Nelly: "Try opening the info menu with {infokey}."]]),{infokey=tut.getKey("info")}))
+   player.msg(fmt.f(_([[Nelly: "Try opening the info menu with {infokey}."]]),{infokey=tut.getKey("info")}), true)
    mem.times_said = (mem.times_said or 0) + 1
    if mem.times_said < 4 then
       mem.hk_info_timer = hook.timer( 15, "info_reminder" )
@@ -508,7 +516,7 @@ end
 function equip ()
    local pp = player.pilot()
    local hasoutfit = false
-   for k,o in ipairs(pp:outfits()) do
+   for k,o in ipairs(pp:outfitsList()) do
       if o == outfit_tobuy then
          hasoutfit = true
          break
@@ -519,7 +527,7 @@ function equip ()
       return
    end
 
-   info_msg( fmt.f(_([["Great! Now you have the #o{outfit}#0 equipped. If your ship is set to automatically weapons, it should be assigned to a primary weapon. If not, you will have to assign the #o{outfit}#0 to a weapon set so you can use that. You can check by opening the #oInfo Window#0 with {infokey}. Check to make sure that is set up and let us go back to {pnt} in {sys}."]]), {outfit=outfit_tobuy, infokey=tut.getKey("info"), pnt=mem.retpnt, sys=mem.retsys} ))
+   info_msg( fmt.f(_([["Great! Now you have the #o{outfit}#0 equipped. If your ship is set to automatically handle weapons, it should be assigned to a primary weapon. If not, you will have to assign the #o{outfit}#0 to a weapon set so you can use that. You can check by opening the #oInfo Window#0 with {infokey}. Check to make sure that is set up and let us go back to {pnt} in {sys}."]]), {outfit=outfit_tobuy, infokey=tut.getKey("info"), pnt=mem.retpnt, sys=mem.retsys} ))
 
    hook.rm( mem.hk_equip )
    mem.hk_equip = nil
